## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

## no critic qw(ProhibitLongLines)
# $Id: Lv.pm 113 2009-07-31 02:26:37Z roland $
# $Revision: 113 $
# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/rhonda/trunk/TeX-Hyphen-Pattern/lib/TeX/Hyphen/Pattern/Lv.pm $
# $Date: 2009-07-31 04:26:37 +0200 (Fri, 31 Jul 2009) $
## use critic

package TeX::Hyphen::Pattern::Lv;
use strict;
use warnings;
use 5.006000;
use utf8;

our $VERSION = '0.04';

my $pattern_file = q{};
while (<DATA>) {
	 $pattern_file .= $_;
}

use Class::Meta::Express qw(class ctor has meta method);

class {

    ctor 'new';

    method data => sub {
		$pattern_file;
	};

    method version => sub {
		$VERSION;
	};

};

1;
## no critic qw(RequirePodAtEnd RequireASCII)
=encoding utf8

=head1 C<Lv> hyphenation pattern class

=cut

__DATA__
% This file is part if hyph-utf8 package and resulted from semi-manual
% conversions of hyphenation patterns into UTF-8 in November 2008 by Mojca &
% Arthur.
%
% This file is available under the term of the GNU GPL, version 2.
%
% Source:   Latvian Lingucomponents for OpenOffice
% Homepage: http://sourceforge.net/projects/openoffice-lv
% File:     hyph_lv_lv.dic (version 0.3, 2005-09-14)
% Author:   Copyright (C) 2004-2005 Janis Vilims, jvilims@apollo.lv
% License:  Lesser General Public Licence (LGPL) 2.1 
%

\patterns{
d4z
d4ž
a2i
a2u
i2e
e2i
u2i
i2u
o2i
o2u
e2u
.vi1s2a.
.vi1s2ā.
.vi1s2i.
.vi1s2os.
.vi1s2u.
.vi1s2iem.
o1pī
ū1rē
i1ta
ū1ga
ē1žu
ū1to
ā1ni
i1rē
i1čo
ā1bu
o1mī
o1kā
o1či
ā1lo
e1čū
o1ļā
e1la
i1šo
o1bi
ē1cē
ā1ru
o1si
u1no
e1hā
ā1nē
e1bū
i1ru
o1sū
a1ča
ā1ča
o1rē
i1ke
o1ra
u1te
i1zo
i1gi
ē1ma
ū1ķe
ū1ca
o1dē
a1nā
ā1ge
e1či
ū1bē
ē1tā
ā1fi
i1zi
o1lī
e1še
e1gā
i1fo
a1ņo
u1to
ī1zē
ū1gu
ā1ša
i1ķi
ū1nē
ī1ma
ā1te
ē1kē
ū1mā
u1zu
o1sā
ē1bu
ī1ga
e1di
ī1te
a1ļī
e1tē
i1že
o1fo
ā1pu
o1hu
ē1do
o1du
ā1ma
ū1mi
e1re
i1ha
i1be
e1lu
ā1ja
ū1ta
a1šū
a1da
ē1cī
i1bu
a1pī
u1ņā
e1zu
ū1no
e1nī
i1no
e1mā
ē1ļa
ū1pā
ā1be
ā1mo
ī1ja
e1ji
ī1re
e1ce
ī1ri
ī1tī
ū1ni
ī1žī
i1ži
a1fī
a1be
e1šā
e1ķo
e1pū
e1ļī
u1ģi
ē1tī
a1ci
e1jē
a1zī
o1lē
u1ga
ī1ci
a1ke
e1ho
i1nū
ū1šī
e1si
e1bo
o1ģē
u1ņi
u1sē
ē1bā
o1ša
ū1ro
ē1ce
i1zī
i1ve
o1ļu
i1dī
o1ku
e1vē
a1ri
u1sā
i1pā
i1dē
o1pū
ī1vī
a1me
ē1ze
ī1bē
u1ķe
a1bē
a1ja
ā1ļo
a1jē
e1fe
o1pu
o1to
ē1vē
a1ki
o1mā
o1lo
a1lo
ē1ķi
e1šē
ū1dī
ū1cā
o1zo
o1gū
o1gā
ī1tē
e1zē
ī1le
e1gī
ī1na
o1me
e1po
e1fu
a1ģe
u1rū
u1ri
ū1jo
e1dē
a1ļa
a1žā
ī1ļa
ē1ne
a1zū
ā1vē
e1so
o1mi
o1šo
ē1sī
ē1ļu
e1ga
i1pē
e1vu
o1ru
ē1ju
u1či
ā1va
a1hu
ī1sē
e1ķa
i1rā
a1čā
ī1ki
i1ti
u1cu
i1žu
ā1jo
u1ki
u1mu
o1ķī
e1ma
ī1ļo
ē1de
o1čo
ā1ču
i1ņa
u1ļa
u1mā
o1he
i1lī
a1de
o1fa
ē1ro
o1sī
ā1ri
ū1ti
o1bē
a1jā
ū1zu
ā1vī
e1ļe
o1ņa
ī1de
ī1še
a1kū
ū1ja
o1dī
e1ži
e1ri
ī1gā
e1ki
u1ze
u1ma
i1vī
ē1pī
u1lu
e1ti
o1čā
a1ķi
ū1zē
a1ļo
i1či
o1ke
a1ģu
i1vē
u1ču
u1ca
u1vu
o1ļa
i1ri
o1ņo
u1co
a1rā
o1jā
ī1bi
e1čī
ē1rē
e1kā
i1pi
a1ka
ā1vu
ū1ža
e1mī
e1vī
o1gi
a1pē
ū1zā
i1cē
e1va
o1nī
ī1ru
e1pā
a1ce
ē1kā
o1ja
a1hē
a1bo
ū1mu
ī1ve
i1nā
i1fi
o1va
u1žu
e1ģi
ē1nī
i1li
i1ņo
u1la
ī1ģe
e1ca
a1tā
ū1zi
a1bū
ē1pē
ī1su
ī1pā
ī1zu
ū1di
e1lo
ā1mā
e1ci
a1ža
ē1to
e1rū
ā1la
u1ķu
o1ģī
ā1pa
e1lū
e1sī
e1bē
i1co
i1ķē
a1šo
ū1ku
u1šā
o1di
a1ņa
ī1pa
o1pi
a1žē
a1si
a1ha
u1šo
ē1mā
ī1mo
ā1žo
ū1lu
e1žū
o1ķi
ā1vā
a1žo
i1zā
a1ku
o1zi
o1dā
e1cu
ī1no
e1zi
e1jū
ā1ņo
i1ce
ū1lē
a1žī
o1mē
i1bī
o1re
e1zū
ū1ra
a1gi
i1lē
ī1bā
ū1šu
e1bi
i1gū
ū1ķi
ē1va
ā1to
u1ce
a1pū
ā1gi
i1ķe
ā1kā
e1ķī
ē1ža
u1ve
u1vo
ē1no
o1bu
a1tī
e1fi
e1ļo
ū1ži
a1tū
ī1ti
ī1la
i1ho
ē1gi
i1fū
a1tē
ā1ķi
a1mi
e1ra
u1ja
e1me
ī1bu
i1pu
o1la
a1ķī
u1šu
o1ža
a1rū
ū1ļa
e1ču
ī1lo
o1nu
ā1jē
a1dā
u1rē
u1rī
ē1žo
i1mā
a1zo
o1žu
ē1da
ī1co
ū1zī
ā1sa
ē1šu
ū1po
i1si
u1zē
ū1ri
u1zī
ū1gā
e1pu
ā1du
e1cē
ē1ji
i1bi
ē1rā
i1ļi
u1nu
i1ki
a1mū
ī1ni
ā1fe
ē1ca
ā1ņi
u1go
a1nu
e1nē
u1ku
ā1ži
ē1go
e1če
ē1za
ā1čā
i1ģe
ī1go
a1go
e1bī
i1ze
e1šū
o1kē
o1pē
i1na
ā1ra
ā1jī
o1za
e1zā
a1lā
e1ņē
a1je
ē1si
ā1bo
u1gā
i1sē
u1ši
u1bī
a1vā
e1ko
ā1šu
ā1ģē
i1mo
e1ļā
i1tē
u1ļā
a1ņē
u1na
ī1vo
ū1me
a1hī
ū1ka
ā1mī
ā1lī
ū1tu
e1je
ī1vā
a1ba
ī1dā
ū1ko
ū1cē
ā1nī
a1ļē
u1ju
ā1žā
ū1mo
i1ge
ā1pā
e1lā
i1ķī
a1sē
e1ni
a1ma
a1tu
i1kū
a1bi
i1jī
ī1ķu
e1fā
u1ta
ē1dē
a1gā
i1lā
i1ņi
e1ļa
ē1ti
ā1bi
a1ši
a1lī
i1ja
e1mu
o1hē
u1jā
ū1ša
i1sā
u1po
ā1cā
a1se
o1ņe
u1fo
ā1sū
ā1bū
o1co
o1ķē
ā1ļa
e1že
u1tī
ī1ku
u1ķa
u1zi
e1do
i1so
o1fi
ē1sā
i1pī
ī1ši
a1dī
ā1ti
u1ņo
u1pa
o1ka
o1cī
i1pe
ī1mā
ā1pē
ā1pī
ū1pē
o1bū
e1ķē
a1mē
ā1rū
o1de
i1ķa
o1šī
ī1gu
u1bi
ā1ka
ā1nu
u1ži
u1so
ē1ka
ā1le
ē1pe
u1ļī
ī1me
u1dī
i1žā
i1du
ē1ra
o1vo
o1fā
o1so
ā1ļā
e1dā
ā1gu
o1bo
e1hī
ā1ģi
ā1čo
a1dē
u1di
ī1se
ē1sē
ā1nā
a1nī
ū1rā
o1hi
o1šā
i1lū
ē1lē
i1te
u1še
ī1tu
u1ģo
e1ši
ū1ba
e1ņa
u1si
ē1zo
ū1kā
i1gu
ū1da
i1sū
o1bī
a1mo
ē1gā
ā1ve
u1bē
e1ņo
ē1vo
ī1mī
u1ļu
ā1tu
i1cī
u1fa
ā1tā
ē1gu
o1ga
i1mi
i1fē
i1ļe
ā1co
u1žī
i1zē
i1vu
a1ju
i1ca
ī1ču
ū1re
ē1bi
e1ro
i1fā
a1he
u1mo
i1jo
e1bu
ī1ro
a1te
ī1ģi
ā1di
i1bū
u1ļi
u1le
a1na
e1tā
e1bā
o1tū
ū1ze
ā1fu
ī1be
a1pā
u1de
i1dū
e1ve
ī1di
a1vo
u1lā
e1pi
u1dē
ē1dā
o1jo
i1žo
ī1ķe
o1nā
e1mū
ā1zā
a1ro
ī1rā
a1že
u1je
a1ti
ū1cī
i1tī
ī1vi
ī1jo
e1co
i1tū
i1bo
ū1pe
e1tū
o1pā
ē1se
a1ļā
ā1ji
a1čo
e1za
ā1mē
a1žū
e1šo
ī1ļu
ū1jā
o1su
e1ja
o1ta
e1lī
o1ze
ī1vē
o1vā
a1vī
i1kī
ā1zī
u1ha
ī1pē
i1de
o1nē
ū1bī
ē1tu
a1ži
ā1žu
o1ņā
o1ļo
i1ņē
u1ci
ī1ca
ū1sa
e1rī
i1bē
e1ne
a1šī
u1gi
ī1mu
a1zā
i1lo
ī1cē
u1lī
e1čo
a1bu
i1nī
ā1dā
ā1tē
ā1ko
ī1šu
o1ģi
a1ta
i1la
a1va
a1še
a1hi
a1ca
e1be
e1žē
a1su
ī1dī
o1da
e1ģo
e1ņu
e1pa
ī1jā
e1sā
a1ņi
ū1so
ī1nu
i1vo
ū1lo
ī1nē
ē1mī
ū1cu
o1žē
ē1jā
ī1cā
a1ču
o1zū
a1lu
ā1lu
o1ņu
a1vu
i1tu
i1ķu
i1ķo
i1ko
a1fa
ī1pi
i1go
i1me
a1fi
e1sū
ī1ju
o1pe
a1sī
a1nē
ū1že
ē1ve
i1po
o1zē
a1ne
e1sa
a1lē
ē1ša
ū1gi
ē1lā
i1mū
u1vā
ū1mī
ū1mē
u1ro
ā1po
o1ju
i1fu
i1jē
i1ga
ū1tā
ē1lu
ū1sā
a1gū
ā1bā
a1la
o1ri
ē1šo
ū1ņa
o1fē
e1li
ē1ko
u1va
ī1šo
a1zi
e1dī
i1da
i1šī
i1hī
i1ne
i1šu
ē1ku
e1ņā
o1na
ī1ža
o1ča
ā1fa
o1tē
ī1dē
o1tā
i1hi
ē1mu
ī1so
e1cā
ā1zi
ī1cī
u1šē
o1no
ā1ņe
u1bu
ū1gē
o1ve
a1ģī
i1lu
i1pa
e1ka
ā1ci
u1ķī
o1sa
o1go
i1nu
ī1žo
i1sī
o1fī
a1pu
a1du
ī1ļi
o1ba
i1fa
e1mi
o1cu
u1ža
ā1mi
a1ķā
i1ču
o1žū
ī1kā
ā1ķe
u1ģē
e1da
ē1dī
ī1čo
ū1pa
ā1de
o1ma
i1dā
ē1ņo
ū1žu
o1ko
a1vē
ā1zē
ā1sā
ī1do
u1cā
ī1ļā
u1du
e1ju
ā1si
o1vē
i1ša
u1fe
o1ji
ē1re
ū1ļī
u1ņa
ā1ca
a1šu
ū1nu
ū1le
e1ķi
ā1tī
o1ge
i1vā
ū1za
ē1nā
ū1ma
ā1ķu
e1lē
ā1sē
ā1li
ī1ne
i1mī
ā1pi
a1mā
a1žu
i1ju
ē1vu
u1nā
ū1ru
e1vi
a1pa
i1bā
o1cē
ā1lē
e1ku
u1lē
i1se
e1vā
ē1jē
e1pī
ē1ci
o1ši
a1hā
a1kā
u1ji
ū1rī
ī1sā
i1ro
o1rā
ū1ki
o1ro
e1ru
o1kū
ē1su
a1ņā
ū1tī
ā1ba
e1ņe
e1nu
ē1te
ā1vo
a1sa
e1nū
ū1žī
o1že
ū1do
ē1jī
ī1vu
o1vi
u1ba
ā1na
ī1mē
a1ji
u1ti
e1mo
a1ra
e1hi
o1te
u1bo
e1su
i1fī
ē1pi
i1ģi
ī1ņu
ū1lī
ā1ro
o1zā
a1vi
o1ni
ī1za
o1do
ī1zā
o1gē
u1zū
u1li
u1da
a1či
e1ta
i1ra
ā1ķa
a1jū
ī1ba
a1cē
u1ra
i1kā
i1zu
ē1nu
a1šā
e1to
u1gē
ū1pī
a1ho
ā1je
ī1ķa
a1ve
o1šu
u1čo
ī1mi
u1sī
a1dū
e1cū
ī1rī
u1ko
ā1ķī
ā1zu
ā1mu
ī1sa
ā1ņu
u1ka
i1ba
ū1vi
ē1ga
ē1ģe
a1rī
u1ša
u1cī
a1co
ī1cu
o1vu
i1je
u1do
o1cā
ā1vi
i1jā
a1ze
a1mu
o1ņi
e1ža
o1čī
i1ča
i1mē
ā1cī
ē1la
e1dū
ū1nī
ī1po
ē1ļi
ī1nā
ū1be
u1se
ū1ci
ī1ņā
ī1ke
ā1cē
ē1sa
ē1li
a1ģā
u1pe
ā1ku
a1bī
u1pu
o1ca
u1ne
ī1ļī
u1mi
e1du
i1ļu
u1pā
ī1ņa
ī1pu
u1be
o1ču
o1šē
ū1šo
ē1me
a1ķa
u1zo
ē1zā
ū1ce
e1tī
o1ķu
ē1jo
u1tū
ā1cu
i1vi
e1žā
a1jo
e1jo
ū1bi
u1nī
ā1ļu
e1zo
i1ma
u1vē
o1jū
o1ha
ū1pu
e1ša
a1ru
a1li
u1mī
ū1ve
ā1pe
i1cu
ū1nā
ī1sī
e1pe
ī1zī
i1rī
ī1pe
o1po
ā1rē
a1ņe
ī1gi
e1žī
ī1lu
i1su
ī1tā
a1no
ī1ži
a1sū
a1ko
i1žē
u1jo
i1va
ī1ji
a1fe
o1pa
e1rē
e1šī
ē1cu
i1šā
ū1žā
e1ģe
ē1cā
a1po
i1tā
ā1ne
ī1va
e1se
ī1ra
o1gu
ū1de
u1dā
i1di
u1rā
ē1nē
a1to
e1fī
a1so
e1ze
ē1le
o1mu
ī1ta
e1ļu
a1zē
ē1ķē
o1ģe
e1na
ū1vē
ē1du
u1žo
i1nē
ī1si
i1ka
ī1fe
e1no
i1le
e1pē
e1ģē
ā1go
i1ni
e1ča
a1čī
ē1be
a1ša
e1gi
i1mu
ē1bē
a1čū
ī1šā
a1bā
ī1du
o1ci
ē1bo
ā1ki
o1mo
ē1lo
o1lā
o1le
a1gī
u1kā
ē1vi
ī1lē
u1čē
ē1mo
a1cī
u1ča
ī1to
a1fē
u1ķi
e1fa
ī1ša
o1bā
a1ļi
ī1da
a1mī
i1gā
a1ģē
e1cī
ā1ta
i1re
ā1me
ū1dē
a1re
ī1li
a1ga
o1tu
u1pī
e1ha
ā1ķē
e1tu
i1ģē
e1kē
ā1bē
o1čū
a1zu
ū1sē
ū1ne
ā1ga
ū1vo
o1ho
ē1ļā
o1rī
ū1ju
o1fu
ū1ji
o1lū
ā1do
i1to
u1bā
u1ge
u1cē
a1le
u1ķē
ī1ce
a1ķu
ā1ze
e1šu
ē1ja
a1vū
i1ņā
ē1na
o1ne
ā1dē
ā1ģa
u1su
u1sa
ē1di
ū1su
e1fo
ē1ni
ī1pī
i1ku
ē1pa
ē1po
ī1zi
i1ļa
i1ši
ē1lī
ā1no
a1jī
ā1gā
o1zī
ā1dī
o1ļi
ā1rā
ē1zi
ū1pi
ē1ge
o1mū
i1kē
e1gū
u1gu
i1zū
a1gu
a1lū
i1cā
ū1lā
o1ķe
o1se
ē1vā
ē1ru
a1fo
e1sē
ā1re
ā1lā
e1ļi
a1ņu
e1jā
ā1ža
ē1zu
e1ņi
u1pi
ē1mē
o1ņē
o1ti
u1pē
e1zī
u1fi
e1ķe
ā1jā
u1vī
ī1ņi
u1žā
ū1li
e1de
o1be
ē1zī
e1hu
e1he
ī1lā
u1tē
e1nā
a1sā
ā1se
ē1ļo
a1ģi
ī1ze
o1je
ū1te
e1kū
o1li
ā1ce
o1vī
i1ci
ā1so
e1ge
i1še
a1ni
i1do
ā1lū
o1žā
o1še
o1zu
a1cu
e1mē
e1gu
ē1ta
a1do
e1ba
ē1ģi
e1žo
ā1gū
a1za
ū1la
ū1ķī
a1pi
ī1nī
ū1šā
i1šē
o1ļe
ē1mi
u1zā
i1ķā
ī1ko
o1dū
ī1ķi
a1ķē
ā1su
ī1lī
e1čā
ē1ļe
u1za
o1ži
o1fe
ū1tē
o1ki
ā1za
e1le
ē1bī
a1di
o1sē
ī1žu
ī1bo
u1me
a1rē
i1ļo
ū1si
ā1sī
u1ni
ī1ka
ā1ļi
o1tī
ā1šo
u1tu
e1žu
i1ža
o1lu
ē1rī
ā1ju
u1šī
a1ķe
ē1so
ā1da
ē1ba
ē1ri
o1ce
ē1ki
i1ļā
a1pe
o1šū
u1ļo
ī1zo
ē1rū
e1go
e1te
i1za
e1vo
u1vi
i1fe
i1ņu
ā1zo
ē1zē
o1jē
u1re
ā1ņa
ē1pā
o1žo
u1nē
u1ņu
ū1du
a1ļu
u1mē
ē1pu
u1lo
i1ji
ā1rī
ī1rē
e1rā
u1ru
a1cā
o1rū
ū1na
u1ģe
ū1dā
u1tā
i1sa
at1tu
eg1rū
ak1so
it1de
eb1lā
et1vī
or1bi
al1ša
ap1dū
ak1na
um1ci
aš1le
ēr1ķe
en1ku
il1ki
ēr1ku
at1nā
at1ģē
us1pē
os1vī
os1ci
an1ra
en1pa
ej1dē
až1vī
as1bu
īs1ga
iņ1di
en1to
uj1me
or1ki
el1zo
ot1nē
es1ko
uz1gu
ak1ti
īr1ni
iz1hi
il1pu
es1ma
āt1vi
ag1rē
on1zē
īb1tu
ap1do
īt1vī
ul1sā
īk1lī
ur1so
ok1tē
ēb1tu
īs1la
et1ve
al1mo
op1ša
en1ce
im1nī
uš1ķa
ek1ti
iz1cī
er1di
ur1fa
an1tā
er1ba
as1pe
al1su
ip1so
al1cī
at1de
aņ1ra
ēk1šu
īg1li
om1ni
oņ1ka
as1le
at1ņi
id1rī
un1ve
al1kū
in1da
ār1ba
īs1žu
al1ka
up1jī
ur1gu
at1sī
īg1mā
āl1ti
al1va
uļ1ku
ok1rē
er1gi
uz1ļo
ak1šē
īm1re
iz1te
āt1vē
ēg1ni
īg1ru
il1cē
ir1mu
ar1ku
ot1zi
ub1na
an1če
om1bī
ēg1si
el1le
av1ru
il1nu
ēs1te
ur1kā
ik1ro
ep1nu
ur1vē
oņ1lu
it1ma
il1ja
ēj1tē
an1ga
eš1pa
āl1ce
ob1rī
ur1vi
up1ri
ēz1tā
iz1čo
ap1ša
uz1ru
ut1rē
ar1to
ež1nī
aš1ļu
aļ1ce
al1ne
is1sī
ib1šo
uz1nu
ut1ņu
ul1de
ār1ho
am1pū
ēl1gu
um1vi
ik1to
ēr1ze
ož1va
ez1nī
am1lī
ak1se
el1ko
ep1si
āj1tu
um1zā
at1ja
al1ķī
az1dā
or1to
ec1he
at1cī
en1ko
ūs1ki
īg1sa
ef1ri
ār1sa
im1po
īt1rī
ed1vi
id1sē
ā1džā
up1la
ēc1te
es1pu
uk1šo
āp1ni
ā1dži
ak1la
en1na
as1ka
ām1di
ag1li
og1rā
ag1dā
oz1vi
an1ku
īk1nē
us1mū
er1ma
āb1ša
in1tu
ob1ti
ap1cu
es1vā
ac1ti
ur1pu
ar1kī
el1la
it1ta
am1le
ik1se
ēk1ti
ar1sa
is1mu
ut1ķe
ār1vī
u1dži
et1nā
id1ka
āl1se
ur1na
ār1zo
uz1li
ān1ka
as1ve
ab1la
aņ1ķe
ēb1tā
el1vā
al1žu
at1pū
at1go
ēr1la
e1dzi
iz1dē
ab1se
at1žē
ir1ca
ēr1su
uļ1ma
el1pe
ej1ve
ap1ve
īg1rā
el1po
ed1lo
it1mo
ep1nā
uk1tu
at1šo
ap1šā
ār1čo
ak1sē
ek1tē
om1pe
ul1go
um1dī
ec1si
ēd1vi
um1mā
iz1mo
ok1zā
āp1ro
āl1ko
āl1vē
ed1po
īl1zi
of1rē
ēj1lo
ap1sū
ip1šo
is1pu
in1fe
ep1ra
at1ša
or1ga
on1gā
ak1šu
at1jo
es1pa
uz1ša
ār1su
uz1be
ik1sī
en1ša
ok1te
ok1bu
ur1ša
or1ģe
īn1ta
ap1ģi
iz1zu
im1tī
ap1te
on1nā
us1jū
ur1no
ab1ti
en1jū
op1so
eņ1no
ur1ka
an1šo
ol1le
ūs1mo
ās1tā
ek1tī
uz1sī
iš1ķā
um1pā
is1po
ob1lē
ap1za
ek1do
ez1mē
ēd1la
uš1ka
of1ri
en1hī
āf1ri
uk1nu
iz1do
ej1ga
ul1ri
iz1fi
ir1na
is1ka
ār1do
en1šo
ož1ma
ēs1tī
at1sā
um1la
oš1pa
eb1to
ez1ņi
ej1ka
iv1žu
uņ1ģu
ik1na
il1ko
ol1mu
im1si
ap1ta
os1tu
us1tī
at1ko
ar1ci
iļ1do
un1či
oš1si
en1zā
ir1zo
i1džā
uz1ba
er1vē
ip1ni
il1zu
in1pū
or1hi
iv1de
os1mē
uz1pū
ām1pi
os1tū
az1bē
al1de
on1de
uz1ce
em1ba
ēr1ļu
at1nē
ār1tū
ur1cu
ir1ku
āv1da
īp1ri
op1rā
ej1ni
am1dī
ak1va
ek1pi
up1ve
ūt1ma
un1tā
aš1ma
āv1ja
um1ti
ūz1mā
im1te
ev1rē
on1ti
ig1za
iz1gū
up1rā
id1pū
ār1cī
ār1lī
el1lē
us1ga
ez1da
ap1cē
ej1la
ag1da
uz1va
op1sē
āģ1ve
el1to
ēz1kū
eš1vi
uz1vī
ī1dze
is1mē
ef1rī
ab1ša
up1ma
ār1nī
aš1va
ab1ri
ob1tā
ik1sā
is1mī
ag1ša
ūr1ka
āņ1mu
ev1ni
or1da
em1ze
āj1lo
at1rū
al1re
il1cī
ār1mi
et1ma
um1da
ob1le
āp1tu
el1pā
iz1ķe
ez1tu
al1tī
ap1rū
iz1ta
em1ža
ar1gi
ēv1re
as1kā
až1kā
eg1ta
al1gā
ap1le
ap1ro
īv1ni
op1ka
ik1vi
il1tī
ur1pī
ir1kī
iņ1ne
iz1da
op1re
ēl1ni
is1nu
ar1cē
ed1sē
ul1ka
ās1ma
op1ba
os1fē
ak1le
eļ1mū
ēb1šu
aš1ra
uļ1pu
oķ1vā
ār1šo
am1di
ār1žu
ed1pu
ed1ve
en1re
ūk1li
uš1pi
ep1ta
al1ve
ad1ma
ez1ce
ēg1tā
ud1rī
im1bi
ek1ra
iv1jū
ez1bi
iz1me
uļ1tī
if1rē
ap1ku
id1ni
og1rē
ēj1de
op1ko
iz1tī
un1ci
īt1ka
ēj1nī
ēr1pē
oš1ļa
at1zu
īv1ga
os1na
og1ga
es1lu
āt1ko
az1va
em1zi
as1ke
an1si
iz1mi
er1vā
ep1sē
al1sā
us1cū
ul1sa
en1ta
or1vē
ek1tā
uz1žo
an1ma
i1dzī
ij1ku
id1la
ēp1ta
ēļ1ko
ur1ti
ap1nī
ot1re
eš1ņu
un1de
ār1vē
uz1ģī
er1mū
o1džu
oš1ni
ij1kā
al1lo
ig1lo
er1rī
em1pu
ug1ļo
ūš1do
ip1ša
ūs1tā
oš1ba
al1lē
eš1da
uļ1ļā
ār1sū
in1de
em1to
ās1tu
ol1fi
or1mā
iv1pu
aš1la
ec1ho
ār1za
ar1ka
ub1sī
ap1zi
ēp1to
āk1tu
er1te
ur1zu
īm1ka
on1ju
ap1go
us1lo
or1na
og1no
am1dā
ār1ta
ēl1ne
er1cā
im1na
uz1zā
ār1no
aj1ci
ip1tā
it1ļu
ag1ri
ār1bū
os1po
ēņ1da
an1kū
om1bē
ār1ve
aļ1ģe
im1ti
al1ti
īņ1ni
in1na
ep1la
uz1di
iž1me
al1tē
in1si
ed1ma
or1tu
em1ta
ug1si
er1be
us1ra
il1mu
ār1ga
eb1lo
īr1rū
īt1re
al1la
et1vi
el1di
ār1ži
iz1ca
ad1da
ēn1mī
ut1sa
ol1po
ez1ra
ir1šā
eg1šo
ud1pu
ud1lē
uk1sē
on1vu
em1pā
ēk1bē
ār1dē
en1zū
āj1re
at1lo
ez1ni
et1ka
iv1ji
in1ku
or1bī
ok1ti
al1si
ur1zī
ūn1ga
ēr1pa
am1bi
at1ro
ēr1bu
iz1ķē
ip1sē
uz1či
ir1du
uh1tā
er1bā
ik1ga
īš1ķi
iz1rū
it1da
ok1ņu
ēg1ta
ir1lo
an1ka
in1dī
es1vī
op1ma
um1sī
on1pa
em1pī
ūk1ko
el1tī
uz1me
er1vī
ūz1na
eg1ru
it1ga
us1du
īt1ņu
ep1lā
ur1va
um1zī
īd1lī
o1dži
ār1bu
ak1tā
er1ta
ēr1no
ēr1pā
um1bi
en1ca
oņ1cū
ēj1mu
at1pī
ēr1gā
ip1re
ār1vi
aļ1ķo
et1ni
ir1gū
āp1ne
ir1su
āt1me
eb1tu
in1cē
aš1ķe
ip1ro
om1da
ep1tī
ef1ra
ū1dza
ēt1ku
ub1li
az1be
ūs1ka
us1pa
ar1su
uf1li
ūr1vī
īs1za
af1rē
uz1ņa
e1dža
iz1bē
ūt1di
en1nī
eļ1ķē
es1ku
az1da
īg1ra
iz1gā
ar1ķī
er1šu
ud1ka
ed1ri
op1ra
ap1li
ap1dī
ed1la
an1rī
en1tī
āb1šo
an1cū
ēj1da
es1tī
er1ko
ūg1ta
el1zu
in1ne
er1bi
ig1me
ež1ni
ad1mi
aj1ni
el1li
ik1šu
āl1pu
ar1ga
et1ta
īc1še
uz1zu
om1bū
un1ku
īb1ni
ar1ža
ēt1ni
is1tu
un1ze
aš1di
it1ni
en1zē
en1ģe
er1pe
uz1zū
ul1si
ur1ca
ap1fa
is1no
iz1ķī
us1vi
in1ho
og1ļu
ūs1nu
er1ga
ir1ze
ēl1re
ēs1li
em1ma
if1ra
at1mē
ur1rā
at1ho
ob1ju
op1ro
ip1li
ec1mā
er1mī
ak1mu
es1sa
īk1lo
u1džē
ur1fi
id1ko
ār1ņu
uņ1ģa
īk1li
iņ1ķe
as1kē
il1de
ār1kū
ul1bo
ez1no
en1mē
ab1ro
uz1gū
ek1ņu
ož1ņā
at1ku
uk1sa
uk1lo
ar1do
ak1tu
ār1du
ik1ci
al1du
en1pe
al1vī
un1ti
ul1le
os1cē
ec1sa
īk1ti
ār1dā
ēb1ju
ap1ču
ub1rā
iv1pa
os1ma
oš1ķe
aš1pu
um1pē
ēp1tā
ek1si
īk1ļu
uļ1ķī
ūš1ka
al1pe
īg1nā
uz1pā
āt1rā
īg1nu
ik1lu
āb1tā
um1ji
ab1so
og1le
ir1te
īb1tā
il1do
em1zē
ar1ģe
ot1ve
ap1gū
id1vā
ār1de
āt1ne
ēt1sa
ad1do
en1ja
er1na
ēk1li
iļ1ņa
uš1ki
iz1nē
oz1va
ez1go
us1bā
ut1ri
ur1lu
ib1re
ej1te
ok1ho
en1zu
eb1rā
em1tā
ed1mā
ah1ti
em1ti
um1sā
az1tu
ur1sī
in1go
ār1di
ap1ņo
īs1cī
al1bi
as1ni
ek1se
al1li
uk1na
al1nē
iz1mē
er1ce
ūs1mu
al1tā
ul1fā
ēk1lo
az1ga
er1zā
ir1gu
ig1rī
en1dē
eč1tu
ep1ļa
ēk1ta
uz1dē
ur1su
īc1ku
it1bi
āk1kā
āp1tā
eļ1ce
ed1rā
ib1rā
er1mi
āb1rī
iļ1ķi
or1mē
em1pi
os1vā
as1zo
af1rā
ež1pā
ūs1nē
ān1ve
eļ1ķi
oš1ga
il1žu
en1va
īt1ra
ak1ri
up1tu
ad1ka
eļ1zī
ir1nē
ec1ve
or1mu
iz1mī
īš1ļa
ab1ve
er1ri
ū1dze
ūz1ni
in1ka
īķ1sa
ud1pe
us1mē
iz1rī
on1rā
aņ1kā
at1ze
āl1re
em1ja
im1sē
īk1lu
ek1va
at1bī
is1lā
os1pī
ār1jā
as1mā
ol1nī
īg1ti
em1po
īg1tā
ed1va
ar1da
or1po
us1ni
al1lā
os1ti
eg1da
uz1bā
ūt1rī
ag1ni
iņ1dē
iz1zo
is1me
at1bi
az1ti
og1ra
en1la
at1do
ap1zī
am1ga
us1ti
oš1ķi
is1tā
at1la
ēj1ti
e1džā
ec1ka
or1ķo
iz1pū
uļ1zi
er1de
uk1ļu
eh1ni
ēg1to
ēl1si
ēc1nā
ap1pā
āl1no
ar1hā
at1gu
ob1ļa
ap1bo
uļ1ķi
uk1lē
es1bi
ar1žo
iv1co
el1mi
ēr1ci
ik1mē
ap1da
uz1ķī
im1pu
īk1la
ag1ru
iz1dī
er1ņa
at1ņu
or1pi
ēp1ni
ūt1ņu
eš1ta
ar1ta
un1ga
oš1ļi
eņ1ģi
an1tē
at1si
or1te
iz1rā
ol1vi
iv1cī
aš1ko
ām1ri
āz1tu
ek1sī
ūk1tu
ēk1ļu
ir1sā
el1ku
ek1su
aš1ļi
iļ1ņu
iz1si
ir1gi
at1ha
ar1tu
em1bu
āt1sa
ek1ļū
en1tā
iz1šu
as1po
ir1ta
ab1re
it1le
ūk1pi
uņ1ne
aš1vi
ām1pa
ār1sē
ok1si
og1pa
ut1rī
in1ji
ig1no
iž1ļa
ēb1ni
uk1ma
ēp1šu
ol1vē
ēz1ta
am1kā
ed1fo
āp1ra
ir1ce
ul1li
as1no
ēt1ra
on1ta
ur1ņi
ur1bi
iz1cē
us1ki
eb1ša
ož1me
an1gī
āv1ji
ip1si
ur1nē
ak1ša
eņ1ku
ab1li
il1vī
is1kē
om1pā
ir1mī
ip1lī
ēn1mā
ēr1šā
āk1da
el1nā
ul1pe
iš1ļo
ēj1pu
āl1lī
ud1ko
er1vi
ak1tē
īs1ka
ag1tā
ī1dzī
at1vu
ar1mē
ar1sē
eb1lē
od1kā
ūr1vi
ot1ņu
en1da
az1du
āt1nā
oņ1me
āl1ba
eb1šo
uz1mā
an1zī
ag1lī
ot1bu
il1po
ēr1ķa
ur1cā
ej1bo
az1ze
iz1žo
op1ļā
īg1šu
ēs1lu
at1mā
eg1lo
īt1ri
ir1tu
ek1sā
ik1ta
eg1lu
ur1vā
un1bē
uz1mū
ež1zi
eg1tā
or1ma
ob1ga
av1ko
el1ba
ā1dzi
at1ģi
āg1ne
ēr1za
ed1rū
iz1hu
aš1ņa
āb1si
uz1ni
et1pi
āz1vā
u1dzi
en1tē
āt1re
ūv1no
um1su
iz1ci
at1ra
uz1ri
or1ta
āk1lu
ik1po
āš1ķi
ār1pe
ap1ķī
uz1bū
uz1pē
uz1si
ir1ža
an1gā
ap1šū
i1dze
at1ju
at1fo
is1ne
ez1rē
as1gā
al1gu
as1ti
ūš1ko
es1tā
al1jē
in1ša
ab1le
i1dža
ēp1ja
eb1ļa
ub1le
ab1tu
ād1mi
iņ1ķo
ā1dža
ek1li
un1li
ek1mē
ok1lī
ēr1pi
ēr1pu
iļ1la
ep1ka
em1li
ez1na
id1ma
až1ne
ir1re
ēt1di
am1zo
ūr1fo
ež1ga
im1to
ūp1nī
at1du
im1tā
ūg1šo
en1si
al1ge
al1dē
eļ1ļa
ap1vī
ār1cu
ež1ģa
iš1re
ār1ne
ul1je
ar1mī
oš1ka
īn1va
ēr1ma
ok1nu
om1ra
ap1jā
us1ce
un1mā
ek1ši
ob1lā
ēr1sā
et1ne
uz1de
il1bo
it1pā
ar1tē
ed1ko
ol1vī
ot1rī
us1se
ēt1ti
iž1ļu
īz1de
en1sā
is1la
ik1te
ob1to
ag1lā
it1ko
ep1ci
āg1ti
ūs1le
ek1lu
us1mā
ār1ze
īs1tu
ar1kū
ir1de
ed1jū
or1fī
ēt1li
ūs1mā
el1no
id1ru
ij1ko
er1ve
ec1la
aš1mo
em1zo
uz1bē
er1fo
eš1ķū
ak1lī
el1lu
ib1li
ek1nu
ir1ņu
aš1nā
ēl1ga
em1nī
iz1vi
us1te
is1ha
on1jo
az1ka
ās1ta
aš1ta
iz1vē
er1nē
uļ1va
ab1lē
an1žu
oņ1ve
il1bu
em1pa
ob1se
em1jo
īv1su
er1co
ur1to
ēg1vā
in1ci
ak1ļū
uz1šu
eņ1la
ūg1šu
āg1tu
ūg1ti
īt1va
er1ka
ol1šū
iz1ču
us1ke
ur1bē
āp1ri
ak1ļa
ūs1kā
os1va
er1ze
ēt1nī
āj1ku
en1žo
uļ1ve
is1ķe
īg1si
ur1me
ur1bī
on1hī
an1di
āj1mā
ep1ļē
aš1ņu
or1vi
ad1vo
az1gu
uz1lū
it1pi
ak1šo
ap1si
ās1to
in1te
am1sa
ap1šo
iz1vo
uz1ve
uļ1ņe
uz1fo
uv1sa
uņ1ķa
uz1ta
ug1ļu
ek1lī
ok1se
ok1vi
až1ņa
oņ1sa
ab1hā
iņ1ci
ug1šā
ek1rū
ij1pa
ok1ve
ap1he
ut1bo
el1zā
or1di
an1go
iņ1zi
ek1mī
ap1bē
on1gi
aļ1me
ab1ru
ig1ti
ur1be
u1dže
ek1vi
ur1ze
ūm1va
um1mu
aļ1bu
āt1ņu
om1re
ug1le
ez1ta
am1bu
at1cē
ēp1ju
ez1sa
at1ni
an1me
uz1no
ār1lē
ul1kā
ar1pu
iz1ru
an1ži
eņ1ķē
od1ni
is1na
em1zā
ār1se
at1ri
it1ru
uš1čo
il1ve
al1ta
oš1vī
ēr1po
il1pi
ap1pē
is1ķē
ēr1sa
ār1ku
oļ1še
uz1pi
av1ro
og1rū
īg1ņa
ī1dzā
il1ze
ez1ve
ūr1te
on1dā
up1da
iz1nā
im1di
ul1gi
az1mē
ā1dze
as1lē
ok1ļa
ak1ce
ūn1ve
ek1lo
ok1tā
ap1jo
ēr1gu
il1nā
iz1he
uļ1ņē
īt1ru
īd1se
ak1rē
āt1ro
at1da
iz1žā
ol1tē
ūt1sa
as1ku
īn1bū
īv1si
or1no
ot1ce
ol1de
ab1pa
ēr1pe
oņ1ko
ok1na
ev1ze
us1ri
ip1ti
eķ1tu
op1ta
īs1ra
er1zē
of1rā
ur1dē
ot1ka
is1zi
ēk1mī
iz1ne
ag1rī
on1si
ir1pē
er1ni
ās1vi
an1za
ēl1gā
ap1du
ek1lā
ār1ņa
um1pa
an1fa
ār1pa
uļ1so
ar1pe
eš1ļa
ēr1vi
ef1rā
og1la
it1pē
in1je
ut1ma
ig1nu
ēr1te
az1gā
āl1de
ār1zi
on1fe
on1ma
ib1ta
at1žu
it1lī
it1ra
ok1be
is1žē
ēz1ma
ār1ti
er1ru
az1ja
ēg1le
an1ni
az1lē
uk1ni
at1lī
eņ1ma
ik1vī
ap1be
ar1ne
ip1ta
ap1žu
az1pu
ak1ra
ul1ve
is1pē
ež1sa
iv1ma
ār1šu
ek1na
os1la
ik1tē
ēs1la
es1la
at1ki
iz1lu
ur1le
īd1ni
it1se
ej1ma
iņ1si
ār1lā
us1va
us1ci
if1te
el1ta
uz1ga
ak1tū
or1ve
iz1ce
oš1kā
ēt1ru
ad1rē
et1ņu
ik1šo
oz1ma
ir1ti
uz1da
ūm1de
el1tē
ēz1ti
it1rē
aņ1ve
ap1zā
at1ga
up1de
ās1na
ap1tu
āp1ņu
in1tē
ās1ne
ap1re
ir1ka
uz1tī
uz1go
at1ļā
ad1rū
ir1zi
īv1mā
er1sa
in1ti
āb1ju
iv1si
ep1jo
e1dzē
el1si
ij1žu
an1du
iz1tā
il1lā
ul1bā
is1cī
ag1vi
āj1rū
os1lo
īk1lā
āb1to
al1nu
āt1ki
eņ1ķī
ol1kū
un1pi
ec1re
uz1ču
ul1dā
en1ro
ir1di
en1ču
ul1jo
ul1ce
az1vē
ap1jē
āl1zī
ūš1ļo
og1ve
ag1si
on1su
og1ca
ol1gu
ār1zā
ig1li
iš1sa
ot1ru
al1vā
am1tī
ās1te
ud1rā
ēt1ko
uz1jē
āl1gu
et1me
ed1ra
at1cū
ol1zā
uz1žā
ul1gā
ok1ļu
īv1ze
at1ve
en1gu
um1du
o1dzī
up1jo
ap1di
ur1rū
īv1mū
ūk1to
iz1ņu
uz1šā
uļ1bū
ez1pi
in1vā
al1ja
in1ve
iz1bu
ap1šu
us1ze
ob1rā
ēk1me
il1le
ēz1to
īk1de
ēj1lu
ar1zo
ec1me
ar1za
ol1bu
ēj1pe
ul1te
īd1pa
al1ki
en1zo
iv1ka
āl1te
ok1no
a1dze
it1va
ār1jū
un1go
iz1ko
u1džo
up1ti
on1li
iz1čā
il1gā
er1gu
iz1za
in1gi
ū1dzo
ur1ni
um1bē
ed1mu
ēk1tu
ār1so
id1lu
ar1me
ir1ši
ik1ša
ej1za
ap1ha
īv1lī
as1ga
eg1šu
iz1bā
ev1ju
ap1ce
ar1di
em1ju
am1bo
iņ1ma
et1si
āk1tī
is1da
id1pu
iz1le
et1no
ul1da
ur1tā
em1ga
ēr1ša
or1mi
ak1kā
iz1mā
ab1vē
ok1pi
ir1bē
īg1tu
ir1sī
eņ1ci
iz1sā
uz1he
eļ1ķe
eb1kā
in1če
ar1mo
ēp1šo
eb1rū
on1cū
er1pa
īg1na
us1ta
ār1rū
is1lī
ēg1li
eš1re
uz1hu
ak1re
īn1da
el1de
um1ja
ak1nē
ob1tu
ek1to
ēr1bē
ir1ci
ih1ti
ov1nu
al1be
aļ1da
ot1rā
ēr1ķē
ud1ma
āv1ju
ik1li
ar1du
uk1su
ak1sī
us1le
āt1bū
ug1ša
ag1mā
ēr1tā
uz1nā
uz1čī
ēs1tu
iv1tū
un1ko
er1mē
or1ci
un1ka
īt1ci
ūk1ni
ār1gā
oz1ta
is1pi
ef1ko
āš1ņa
ig1ni
ur1cī
aņ1ķī
ec1ti
il1tu
ul1su
an1jo
ek1vā
al1po
uk1tī
āj1ni
ām1ja
ēr1li
ah1tu
at1vē
il1nē
an1ke
as1ci
er1je
es1nī
id1gu
ān1va
us1fi
ār1si
ēd1va
ul1vā
el1ni
eš1ma
un1la
al1ma
un1du
an1ho
ul1šu
el1mu
al1žī
el1rū
ul1ci
ar1ģi
at1vo
ēr1bi
il1vē
us1me
at1li
uz1mu
av1da
ēg1tu
uz1ļu
eg1vī
ēb1to
ad1ju
ir1mo
or1fē
el1nī
iž1ļi
em1de
ap1pa
ūg1ša
ul1bu
ēr1mu
as1vi
eb1ļā
as1pi
ir1sū
uz1vē
ās1nī
ur1zā
ir1bo
īk1da
it1nī
ar1pa
el1do
ēr1le
or1fi
ēt1la
aļ1ļi
am1bā
āš1ņā
us1jo
eļ1ni
eļ1nī
us1ja
in1gu
ig1nī
ed1ru
uj1bi
os1te
em1va
ar1lo
ig1lu
ak1lā
un1ba
iz1bū
am1ze
is1ti
it1ne
uz1sā
ep1lē
iz1bī
ār1nē
eg1la
iz1du
ēg1dē
ān1za
es1lo
im1de
at1hi
ar1ķi
iņ1ve
ēr1zē
uz1lā
ir1vi
ār1ru
oš1ļu
at1te
at1žā
un1su
on1tā
od1la
ār1ģe
ēs1lo
al1kā
aš1pa
ūz1ne
ār1čā
ur1je
uļ1ķa
ak1ņā
īr1fa
es1kū
ār1ši
ar1ba
ār1ša
ir1dī
id1nī
uk1da
uz1žu
ār1va
ot1ra
am1do
iz1ģi
ep1lī
em1si
āl1ta
in1su
ol1ni
ub1ļu
iz1ņe
ap1ča
el1za
ob1jā
uk1tē
ap1mā
al1ri
ot1za
ir1dā
av1ni
ūr1mu
it1mi
og1ļū
er1za
ek1lē
ūg1te
it1mē
oš1ņa
āk1le
aļ1čū
ān1lī
e1dzā
um1be
et1rī
ek1sa
al1le
uļ1ka
iv1ni
ēd1mē
il1dī
ul1ti
ot1le
at1gā
iņ1sē
at1ca
aļ1rā
ab1su
īn1bu
ip1rī
uz1ra
uļ1de
em1ko
at1čo
op1vē
a1džu
uz1ķi
ir1ma
ur1bo
iz1pe
em1tu
āč1sū
um1šo
ap1ķē
āl1sa
as1fa
ož1ņa
em1dī
ūz1da
el1pi
ir1sa
āz1mo
ed1ro
il1si
īk1na
uz1cu
os1pu
ag1šo
iv1va
īd1vi
iņ1ro
ār1ču
id1ne
eg1pu
um1ko
uš1ķo
ār1ka
īļ1bā
ak1ve
ez1gi
or1la
aš1pā
īg1va
ir1šī
iļ1li
ēr1sī
um1ši
īm1ju
ub1je
ep1li
at1po
āl1ma
am1bī
iņ1ķi
āj1ra
as1tū
eš1tū
en1te
īv1ma
et1nī
āb1pu
os1ku
is1tē
ok1ļi
iz1rē
iz1ži
el1nu
iz1pā
ul1tā
oļ1ko
ēv1vā
os1lā
or1tī
āb1tī
af1ro
ēl1zī
āl1ru
an1šu
us1tā
or1do
er1ci
īs1ri
ēd1ra
im1da
ar1be
il1ku
iz1mū
it1rā
up1ša
uz1sū
us1ru
ir1do
ur1ga
ek1re
al1nā
ok1ni
ek1šu
ob1rē
ir1žo
ār1dī
eļ1ma
aš1ci
il1pa
ū1dzu
ek1ša
ār1mo
il1gi
uš1ņa
el1mū
ās1ka
ēk1ša
or1ķi
ār1nu
az1ru
ās1tī
im1šo
um1ze
īv1so
ūt1nī
ap1fo
ag1šu
il1ma
īc1ga
ēr1tu
es1mi
ūs1mī
īs1ti
ej1vi
uz1na
on1na
id1ro
el1mē
os1pe
op1lu
ēc1ka
ar1pā
up1ci
ūs1ma
ag1re
ūž1ņa
ol1ga
an1ta
un1di
al1ko
ul1lā
ir1ko
ī1dzo
os1vi
es1lē
us1ma
ec1mo
iz1ve
az1ra
āl1cu
id1rā
an1ža
oņ1zī
um1tā
af1ra
um1vā
ār1rā
ab1vī
ū1dzī
i1dži
ēg1šu
in1ža
ed1ņe
ec1tū
or1ne
eg1ma
āp1ja
ār1šī
ep1re
is1ve
ol1fe
op1ci
as1te
ār1šū
ež1ku
iņ1tū
es1te
ek1ta
ēl1cu
ār1na
us1jē
il1te
āv1ra
āv1ce
aļ1va
um1ni
ak1ni
ār1rē
et1ri
u1dzī
on1tu
up1le
am1bē
in1to
ād1nī
in1ta
ol1ma
īk1bu
an1žā
āb1ma
ur1ķī
ak1vi
at1nu
is1bi
ol1ve
og1ne
īv1bi
ok1lu
ār1čī
ug1ti
īn1ra
ig1to
uļ1ģi
ār1ma
um1jī
ē1dze
ap1rē
is1nā
ūp1ko
un1si
il1tā
ap1ņu
ol1be
os1mi
ig1la
īl1ni
or1bū
ip1ru
ak1cī
eņ1ķa
ez1gī
oņ1sā
āz1ni
ān1pā
us1pu
ād1ne
us1po
īn1de
āk1ba
ā1džu
ur1sē
at1ba
āp1ti
ūv1vi
ah1tā
ut1nē
em1be
ap1na
ul1pa
ob1je
āk1ļa
ib1ti
os1ve
ud1vi
en1pā
āv1ni
iz1vā
eg1ro
op1si
ap1pu
am1ni
at1ta
ak1li
es1ne
uv1ju
ar1rī
i1dzu
es1rē
ob1lo
es1li
og1ma
uš1ko
an1zā
ig1tu
an1be
im1pē
ic1sa
eb1ka
uz1zī
oš1ma
at1nī
am1dē
uļ1ba
ār1mu
up1jā
ār1he
es1mē
er1ha
ēl1di
ih1re
op1ja
il1go
uv1ve
ul1pu
il1du
aš1mi
āl1ve
ār1lu
ez1pu
at1so
īs1ca
ek1ni
ēg1nā
ūt1ro
ap1ķe
ab1pu
iz1nu
iz1ņē
ēk1ne
ež1jo
es1po
ās1no
ūv1ni
aļ1sa
aļ1ķī
ē1dzo
ip1no
ap1vā
īk1tā
ār1čū
uz1ze
uz1nī
on1du
ap1hu
ez1nā
uk1ļi
ul1bi
ad1pē
at1pē
ēr1zu
uz1čā
ēs1to
aš1gā
āt1no
en1vē
is1be
et1rū
āk1ta
uk1tū
ij1ni
ug1šu
us1ķi
ij1ve
el1šu
ul1vē
ēt1rī
ag1ļē
es1pe
ēr1šo
ak1rā
eļ1pa
ec1rī
ez1lo
ēk1lu
el1va
ār1ķi
eļ1po
am1pa
ūt1ni
iš1zi
id1mē
uz1dū
ēk1la
iņ1ta
ol1tā
īk1ša
īt1nē
iļ1jū
it1tū
is1pa
ap1sā
iz1so
ež1ģī
ud1ri
oņ1nā
am1lū
iz1pē
ak1vā
al1te
ad1ri
ak1ga
ār1bā
ap1rī
or1bē
af1ti
uz1du
at1ši
ug1tu
iv1zi
an1se
eg1to
ūd1rā
os1lē
ār1ri
el1ga
ēr1de
ir1tē
em1ļa
us1na
im1do
āt1ve
ur1ma
ur1ģi
īg1ni
īd1ko
ūd1ra
iz1vī
ed1rī
at1jā
il1mo
e1dza
ēk1to
ār1ģē
iļ1ņi
iz1bo
as1ro
um1zo
or1pu
ar1kā
ik1ko
ap1ca
īs1ba
as1vā
at1mo
uz1pu
ēn1ga
am1ba
uk1ši
ag1to
iz1zi
uz1tu
ul1ni
er1lī
eš1ķē
en1zi
at1zo
ir1ša
ez1si
us1so
am1fī
ig1tā
e1dzu
ap1kā
ār1ro
es1vi
ag1la
ir1mē
ad1ve
it1di
um1no
ap1lā
in1ga
op1šo
a1džā
er1po
uz1bī
un1ra
uk1ta
ar1ve
īn1sa
ap1vi
ēr1ce
og1lū
aš1li
aš1po
e1džu
ap1mu
ag1lu
or1be
am1ne
ol1di
iņ1ģe
it1na
eļ1ņu
uz1lu
ās1me
ār1sī
ur1ku
ur1pe
ep1na
ut1na
ac1da
uz1le
ik1ka
ar1fi
ab1si
er1zī
ār1ļu
ap1ja
ul1tu
is1di
an1ge
ar1lī
ug1tā
on1so
ud1kā
eļ1ko
iš1ķī
um1po
ik1ļa
ūg1tu
ār1gi
ēr1ni
et1va
ap1lo
ēr1ķī
iz1tu
īv1la
is1ju
od1ba
az1ro
ūs1di
up1tū
ūs1nī
eļ1lo
ap1bī
um1ta
īs1tī
eb1rī
uš1ķē
ep1tū
eb1lī
or1že
up1ra
ēt1ma
ak1ro
ir1la
at1či
og1lu
ūs1ku
ut1rā
il1no
ec1de
an1bā
az1vi
ān1ga
ēj1ce
eļ1ve
er1zi
el1sa
īk1ta
īt1rā
ār1fe
um1ka
ir1si
ag1ļi
ip1ka
ak1šā
ar1ki
ek1ļā
ar1bā
ed1da
os1le
iv1ja
iv1kā
ūk1šo
uļ1vē
ēk1tā
oš1ņu
og1de
ok1ļo
ul1dē
ik1sa
am1pē
ūs1no
um1to
us1ču
od1ka
as1lo
op1mī
up1to
oļ1ti
ū1dzi
īr1ma
os1kā
al1dī
ok1va
el1tu
ap1pi
is1ca
os1ce
āl1vi
ir1mi
uš1ķi
oz1tā
is1te
ig1ša
at1rā
ar1žu
os1kū
im1ša
ār1to
um1bo
an1sa
aļ1ļa
ēk1di
āj1ka
ak1tī
ar1tī
os1tā
eg1re
im1sa
ul1sī
ag1me
il1lē
on1ce
iz1jā
iž1ci
or1ku
az1no
im1pā
of1se
op1ļē
āl1ka
ēs1ti
oņ1de
er1la
ār1ņē
uz1ku
ab1pi
ar1na
em1ša
er1ku
im1pe
in1tī
es1mī
īv1do
uz1mo
uš1mi
ak1lē
aļ1la
up1lā
ok1ta
ūv1me
em1žē
āl1rū
is1pā
ar1le
eš1va
eņ1rā
ad1ne
on1ku
īs1si
ab1da
il1lu
ar1va
an1ko
ez1bē
ež1li
il1ga
at1tā
iz1kū
ar1nu
ir1mā
ad1je
ik1ra
an1bu
op1ri
ik1vā
ek1šē
ap1ru
uz1ņi
iz1be
at1vi
it1ro
ur1tē
en1po
ap1jū
iz1ģī
ol1rā
ar1go
ah1lo
im1pa
ī1dzi
us1lu
ir1žu
at1cu
am1vi
ag1ti
im1ju
ep1ļā
ec1ga
on1di
ān1kā
is1fu
at1ņē
āņ1ti
at1čū
az1pa
ik1pa
ov1bo
ad1si
er1lū
ir1bā
um1tu
uj1ko
ež1vī
ab1lo
ūk1la
os1pa
ul1to
ap1žē
āv1ma
ez1zo
eg1mā
ap1to
iz1ku
os1lu
or1vā
ok1rī
os1to
al1di
is1lu
ē1dzi
āt1li
aļ1li
an1ču
eb1la
eņ1ķo
ak1rū
en1ri
ez1be
ēr1nē
eļ1ņā
ab1rū
un1sa
iz1zī
až1da
ūv1so
aš1ķī
it1kā
ap1bu
ē1dzē
a1džo
īb1šu
us1lā
ad1re
ej1le
ek1ro
at1su
ap1ļu
ež1ci
er1ra
ez1vē
aļ1ko
og1re
ur1ja
er1zu
ār1me
av1tī
on1tē
at1fi
ir1bi
ob1li
uz1jū
aš1ļa
āb1ra
ur1bā
ap1nu
al1ģi
an1vī
on1dē
ep1tē
ez1de
um1de
up1ju
īg1te
od1de
ok1sā
at1jē
ār1zu
um1di
eš1di
eļ1mo
iz1de
in1gā
ač1gā
ip1se
iš1ķē
ūn1ze
āk1to
eš1vī
ēņ1ve
ap1la
oņ1ni
im1ni
ut1ro
et1de
ep1pa
aš1re
up1ja
us1pi
uj1la
āt1ti
op1le
an1nu
ēj1mā
as1lā
am1mi
az1dē
am1po
īk1pi
ūk1tā
ār1go
ap1ma
uf1ra
īg1ta
ad1ca
ār1ķē
ek1vo
am1te
iz1zā
ar1ke
ēr1mā
en1dā
eg1lī
at1ci
ur1ci
āg1la
af1ri
īk1ze
er1cu
ad1va
el1ci
ep1no
ag1ne
ār1zī
eg1rā
eš1ķī
an1ti
iļ1dā
ud1mu
āl1li
ub1ve
uz1pe
uš1ķu
eļ1tē
or1čē
og1pu
eg1nē
op1la
al1dū
ef1rē
īt1ni
ek1nā
āz1be
er1ti
er1no
os1fo
ēr1ga
at1ka
er1go
or1ķe
er1mo
un1da
an1žo
ez1mi
ef1pa
ek1rī
ūp1li
eļ1te
ār1tā
ot1ri
ud1li
us1zā
as1tē
iv1da
is1ko
il1za
īg1to
uz1bu
er1tē
ap1su
es1zi
u1džu
uk1li
iz1lū
it1ti
īk1kā
es1pī
uz1vu
ūž1di
ūs1li
āl1po
ok1re
āk1ļi
īž1me
eš1ķa
at1ķe
āt1rī
iņ1ši
ap1ga
um1jā
īm1ja
ez1ro
iz1jē
es1sū
eš1vā
og1ri
ār1lo
al1so
iz1lī
is1kā
ep1ti
eg1bi
ār1la
ar1vo
ēp1si
ār1gū
eļ1ga
uz1kū
iļ1le
o1dze
an1sē
at1no
ok1ma
al1sa
ek1ri
ep1le
en1rī
eš1de
ez1jū
ik1sē
al1gi
ep1ro
īv1ci
id1po
oņ1pi
od1ra
ej1pu
ir1go
el1ma
in1se
et1sa
īb1ša
aļ1ķa
ol1la
at1rī
at1dē
īļ1si
ār1ņo
ur1mi
ep1lo
āg1šo
ec1to
ob1ve
up1tā
āt1ra
os1ko
al1zi
el1du
iz1vu
ār1pi
at1šā
ul1tū
il1dē
ap1mī
ar1lē
er1tā
us1mu
is1hu
oņ1si
āz1ve
īp1ne
āz1to
iš1ma
ol1vā
em1zī
āl1be
al1šo
us1ko
es1ga
in1fa
āj1vi
at1di
at1ži
ap1bā
ah1ta
ēr1nā
el1me
īs1le
iz1ja
ēb1ti
es1ka
ul1be
ep1ri
ež1zī
ot1vē
as1la
at1ru
er1mā
ed1re
ēj1ma
av1ci
ak1do
us1nē
eš1ga
ap1cī
āt1zī
as1pa
āk1ša
es1ta
ib1lo
er1ģi
ēr1mī
eļ1di
at1lā
ak1te
aš1vī
og1li
al1ga
aš1kī
ār1fi
es1to
ūt1pa
on1ko
ār1ci
ām1ju
el1ce
īs1tā
ec1ni
al1ku
at1hu
er1fe
ār1mē
ēr1mū
ul1di
on1ga
ār1pē
ar1pē
ās1nā
am1fi
āt1pe
an1co
oš1ņo
eļ1ņi
aš1no
īr1na
āk1šo
et1ko
ig1ma
an1te
an1ba
e1dzī
ek1šo
um1bu
ir1gā
om1le
ūm1ve
al1na
iz1va
og1lā
ūk1ta
il1so
uz1ma
il1ša
oš1ķū
at1zī
ās1mo
ēr1na
ūž1ņo
um1nī
eg1vi
al1tū
on1se
iz1ža
ek1te
ep1lū
ep1se
os1tī
as1ta
ār1be
iz1ša
oš1ķo
āg1ri
īv1ku
āt1na
aš1ķi
ēr1dē
ir1tā
ak1sa
as1to
az1jū
un1me
ap1pū
ep1to
ur1ve
en1ma
ēc1na
eņ1ķu
ār1le
um1zi
uz1cē
ez1pa
os1ka
ab1rī
er1ģē
et1ra
īt1na
ap1čī
ok1ri
eš1pe
iž1ma
is1ša
āz1ģe
on1dī
ep1tā
am1zi
īg1lo
iv1re
at1lu
āl1ci
ez1vā
iz1ti
al1mā
ug1li
il1bi
iļ1ķu
aš1ņā
iv1ba
ik1ši
īk1me
ap1kū
un1gi
uk1nā
al1vo
up1lo
oz1vē
ēj1ka
ap1rā
ad1li
uz1ju
el1pa
en1li
at1ču
īk1bū
at1dā
up1ta
iļ1ņo
ar1pī
ak1vē
ēc1ga
eb1ne
af1li
ol1ka
ez1fo
in1ki
an1gi
ak1lo
up1si
ej1va
ag1tu
ek1ļo
iž1vī
as1zi
ir1lī
en1du
uz1tā
if1lo
eļ1ļo
ob1lī
um1sū
on1ci
an1de
es1lī
ēb1si
ib1tā
il1da
uķ1ko
uk1ša
āj1pe
ej1bu
ūv1ka
ar1fa
oz1ve
īk1rā
up1mā
ūs1to
ir1nī
ag1lo
oņ1ra
iz1sū
īg1ce
an1dū
iņ1vī
e1džo
ār1da
īn1mā
ār1ju
er1vo
ar1se
i1dzē
iļ1pi
it1pu
ur1sa
id1da
iš1ko
eš1ķo
ār1po
ev1kā
īk1rū
os1ri
ik1no
ār1tu
ur1ko
oz1tu
om1pi
ar1šē
on1nu
uņ1ģi
ur1šu
ab1rē
īr1kū
en1cē
em1je
ap1va
av1ļa
aļ1bi
uz1hi
in1ča
on1fu
ār1sā
oš1mī
uz1rī
il1ka
un1tē
as1mi
iz1ga
ār1mā
āk1tā
ik1lo
im1pi
or1pa
aš1ro
um1mē
īn1te
ež1rū
ab1sa
uz1mē
a1dza
as1sa
un1gā
ag1mī
eš1mī
eg1ša
ak1ru
ēt1ri
or1se
us1no
it1mā
uz1po
in1čo
iz1su
is1to
uk1vi
ir1to
um1ju
uļ1sū
in1dā
um1tē
ar1šo
īk1ko
er1me
uk1si
īv1pi
ēr1mē
as1tī
in1kā
en1za
al1bu
or1ģi
a1dzī
en1sa
īs1ta
eļ1de
ū1dzē
uk1tā
ec1vi
ūk1le
ap1čo
ēd1ni
ān1ce
if1tu
īk1di
āl1va
ap1gu
en1de
ar1de
ap1mū
on1te
es1da
ud1ci
at1se
ūp1ni
in1ha
ap1de
al1ci
ir1pu
um1va
ok1tu
ug1lī
aņ1da
ep1ša
el1su
īk1si
eņ1ģe
aļ1fi
er1si
op1ju
od1le
īt1pa
ak1nā
ap1nē
ar1dī
ek1zē
at1zi
āt1ka
āl1mē
em1za
um1pu
ap1žo
ēj1sū
en1le
iz1lē
er1zo
um1dā
ur1žu
eh1no
ab1ka
īs1vē
īb1šo
as1se
ul1lē
ir1ki
at1ča
uļ1ķe
āz1ma
ip1nu
ar1nī
īg1lī
ad1ra
ez1ti
īk1ra
ūr1zi
ap1vu
ib1la
īt1kā
iļ1da
ēl1ko
ob1la
o1dza
ep1nī
es1ri
up1ji
eļ1ku
ik1ve
es1vē
er1lo
um1do
ik1lā
em1žo
is1so
om1ju
ij1ka
en1ni
āz1ne
īv1di
if1to
un1je
er1da
en1kā
ūt1ra
en1ge
āp1ji
oņ1kā
al1vi
ēr1zā
en1ga
īr1ku
ar1te
up1rī
or1ti
ar1ķē
el1lī
iš1la
an1no
ec1pi
ēk1šo
an1da
āp1šu
iļ1ru
ež1lī
ed1rē
ed1ka
at1kū
īb1si
ež1ņa
am1va
un1dī
ār1nā
al1me
uļ1ze
es1tē
āj1ba
āp1šo
ap1po
en1zī
er1sī
ig1ro
at1bu
um1sē
el1cē
ās1ni
ar1pū
od1ve
oz1ga
in1do
uz1mi
un1mē
uz1ka
ig1ne
et1pa
ol1si
ab1ra
on1to
os1kī
aš1ķa
iz1se
īn1pi
eb1ru
es1nu
ūt1ru
ik1ri
as1lu
iz1la
uz1ci
at1tē
on1da
āp1ša
ēp1ne
or1ce
ep1rā
ūr1mā
ež1vā
up1jē
eh1lo
īg1ņā
us1li
ec1tē
āt1mā
ak1nu
u1dzē
ez1ne
ar1dē
ēk1da
et1nē
ež1ro
ir1kū
ap1lū
īs1tē
us1ba
ēj1zo
ī1dzu
at1le
ēg1na
ep1tu
i1dza
af1ta
ep1de
īļ1ve
od1ro
um1šā
en1se
eņ1ra
as1tu
at1pu
eļ1da
āb1ba
iš1ķa
āg1ša
il1bā
ūš1tu
ud1sa
at1ģe
um1šu
aš1mā
en1so
eg1ba
am1re
ud1ro
ov1na
ik1re
ār1rī
ār1ni
ež1ra
i1dzo
īs1to
an1še
ar1ju
iz1ģē
az1dū
ēr1me
oņ1ga
ēr1tē
id1mo
īs1fi
at1mī
al1se
il1ha
ep1ja
il1ce
of1ra
um1pi
uz1rē
aš1ņo
el1ža
ap1ņē
ar1bu
iņ1re
ij1pu
er1žo
ol1ta
ez1va
aļ1ķi
il1nī
ag1no
ul1lī
ib1ri
āt1ri
um1pī
ūg1tā
is1fē
ak1su
al1to
el1žu
ap1ģē
iv1ga
al1za
aļ1dē
ēr1si
ār1ņi
et1rā
aļ1ņi
um1zu
ūg1si
az1mā
in1ko
īg1ri
il1šu
er1va
uz1tū
ec1cī
īs1li
a1dži
u1dzā
am1žu
uz1fi
iz1nī
ir1dē
ev1ga
iz1ča
iz1pu
up1šu
iz1gu
in1ce
uz1dī
āb1šu
or1ba
i1dzā
a1dzo
es1tu
āz1ti
el1mā
ap1vo
ub1lē
aš1ķē
īs1vi
en1jo
as1ki
ik1tī
ok1le
ur1ķu
in1gī
ek1ļu
uz1to
uk1le
ir1bu
āg1to
uz1ne
as1ko
ek1rē
ur1do
ob1ta
ār1jo
uk1no
ot1lī
ur1te
uz1re
at1ma
at1žo
ēd1ne
at1na
us1ka
al1vu
ib1šu
iz1dū
ug1ko
uz1vo
at1zā
eg1zī
ūš1ga
il1ni
uz1ro
el1pu
ūg1to
os1mā
ul1ma
as1ma
al1ni
ut1ra
ug1šē
at1sē
in1fo
eļ1bū
uz1jā
ēt1va
ēk1ba
ik1di
īg1le
op1ne
ur1vī
ār1dū
ir1cē
ēr1sē
as1ja
es1mo
il1ci
az1li
em1šu
ap1lu
er1nā
ot1rū
uz1čo
as1dē
os1mo
aļ1ga
un1te
at1ne
om1ba
ok1ra
en1vā
ap1sē
an1dē
ol1dē
ap1ļa
ek1sē
ad1so
iz1po
uz1lī
īk1ne
ud1ra
uz1ko
ur1ta
ep1šo
ud1mi
ār1ki
eļ1vi
ūk1ti
īg1ro
iņ1ti
ur1du
eg1tu
ār1bo
es1mu
ar1ce
os1ki
iz1tē
ev1mā
ān1ko
er1ge
ē1dzī
en1ba
īv1ba
ot1mu
ēb1ta
īn1rū
ūk1ņa
op1jo
is1lo
ob1ru
ur1li
ēs1le
ur1lā
ēj1rā
ul1ko
āg1tā
iv1ku
ām1ga
o1dzē
ī1dzē
ir1za
ip1rā
at1tū
iv1vi
op1lū
āp1si
em1me
ap1žā
ār1mū
ik1šā
il1ba
an1ze
on1do
il1he
ek1ļa
el1nē
āk1re
uk1se
ēr1so
ef1re
ūt1rā
ip1tu
am1pā
ak1ņu
at1me
ūr1ma
ik1tā
am1pu
az1de
en1ki
iv1mo
ar1ge
īb1ti
uj1ma
os1ta
as1na
ēs1ma
om1bo
eb1rē
er1ža
āt1nu
ež1ko
uz1tē
up1ni
ig1nā
an1na
az1ku
on1tī
ar1sī
ek1tū
eņ1me
os1vē
ak1šī
at1rē
er1bu
eļ1ņa
og1ro
īt1lī
ij1ro
ūk1si
ār1žā
ap1dā
uz1pa
ek1ļi
iz1tū
aš1ķo
im1ta
ik1nā
at1jū
ēg1no
ā1dzē
em1te
er1ģe
āš1ņi
eļ1ta
ap1lī
ul1la
uz1bi
īt1di
ud1bā
en1tu
un1ne
uk1so
īv1ti
ol1je
ed1li
iz1ni
ēr1šu
eb1si
ēv1ze
uz1za
er1ne
om1pa
ec1kā
in1sa
uz1ža
ūs1ta
ap1ļā
ūv1ga
iv1ri
aļ1ba
ob1ša
ir1zī
aš1mē
āt1ru
az1sa
iš1ķi
ok1nā
or1mo
iļ1ļa
iņ1ru
uz1gā
uz1vā
it1ri
om1de
is1cē
is1mi
op1ga
at1čī
ar1nē
uz1ho
at1bā
ir1ži
el1fi
ir1ne
ar1dā
uz1fa
ap1ki
ur1dā
āl1ze
ār1li
or1bu
ap1ti
um1ga
ek1ņa
al1pi
us1fa
ār1vo
uz1ģi
e1dži
ig1nē
uz1te
ot1va
ag1ļu
os1pā
īk1ņā
īk1šu
e1dze
iš1jā
ek1ve
at1ļa
āl1si
or1zā
ul1lo
ab1va
aņ1ķi
ār1ķe
ur1vo
ap1ze
em1ni
oš1ņā
ūž1za
ēr1cē
ap1hi
ek1nī
uz1ņe
in1tā
un1cē
ib1lā
īr1ga
is1ku
uz1zo
ug1ši
am1zā
as1me
un1dā
ak1sā
it1ļa
ur1nī
uz1ņē
ēz1tu
ab1tā
ār1šā
us1sa
īg1šo
eņ1ca
op1lo
āp1to
el1mī
eč1zi
eg1ku
al1pē
ik1rī
al1vē
it1ļo
em1mē
iz1ba
is1dā
īd1mē
en1ve
ap1ju
ol1ko
ag1le
ap1tē
āt1nī
āv1va
et1so
an1hi
eš1kā
ir1šu
es1lā
os1me
is1tī
ur1ne
et1nu
ap1mi
ūz1ma
or1mī
as1za
an1cē
es1ni
al1fa
ēr1bo
ur1ģe
āg1si
is1de
īs1sa
at1mi
ēš1ļa
ūg1da
ūs1nā
ār1ra
un1kā
ok1li
ē1dzū
ēg1nu
al1bo
op1da
et1ķī
ur1pi
ār1pu
ok1sī
it1ļi
ap1sa
ip1ci
ar1ša
av1ma
ec1vā
iv1do
ūs1ti
at1dī
ār1žē
am1na
ak1ļā
iņ1me
uz1ha
ar1mi
eļ1ļi
ēp1tu
of1to
ag1rā
il1zī
ēg1šo
il1sē
is1ba
ap1ko
ug1šo
ot1mā
iž1ni
ār1tē
at1šu
ep1šu
uz1ģē
ag1lū
up1lu
ām1gā
ar1šī
it1ve
ak1ma
už1pu
uk1te
uz1lo
ik1ce
eļ1rī
et1na
āl1ra
oz1ti
iz1ze
ap1zo
ir1nā
ad1le
ēt1ho
ad1mo
un1ta
a1dzi
az1ko
āl1pa
uz1nē
ug1ma
en1di
iz1šū
ag1rū
īr1ra
as1pē
ok1ce
en1cī
il1mā
op1su
al1šu
of1li
ev1ma
ab1ļā
a1dzē
ud1ru
ir1zā
od1bi
ol1dā
ap1ci
il1dā
ok1pe
an1ki
as1vī
od1ru
ur1pā
āj1ga
ēr1da
ep1ju
iz1re
iņ1ka
ār1mī
at1lē
ir1sē
iš1ļa
ēg1ša
āš1ņu
ar1gā
av1la
aļ1ni
iz1fo
il1la
er1mu
up1šo
is1ma
āl1sā
ap1ļē
ur1dī
as1tā
ul1tē
es1cē
ud1lī
on1ve
uz1ģe
ek1me
āš1ņo
ek1la
āl1ga
iz1di
on1vo
er1tī
on1ja
uļ1žo
ār1fo
ak1rī
ev1bi
ij1ci
eš1ra
um1jo
az1me
im1šu
aš1da
or1tē
uz1rā
ār1vu
al1ba
in1ge
ab1na
an1ci
īs1lā
il1šā
am1za
al1jo
ek1le
im1dā
iņ1de
oļ1va
iž1ra
am1mē
ok1rā
er1le
ok1vē
ok1rū
uz1ķē
eb1ti
āv1la
a1dža
iz1ļu
on1ka
uz1do
ār1ķī
ē1dzā
an1nā
āģ1zo
uz1ča
īt1bi
am1da
at1kā
ēj1ko
ul1du
op1lā
uk1šā
ik1nu
oh1ro
at1ti
eļ1dā
it1li
uļ1ļa
ūs1mi
at1he
at1to
ec1pa
aņ1pa
om1bu
ig1tī
ap1me
er1so
an1tu
on1fi
aš1ni
īv1ja
oņ1ma
il1rū
ap1pe
em1di
ār1pī
er1žu
it1rī
al1tu
iz1kā
an1gu
im1tu
an1va
īn1dā
el1ti
ap1sī
ēr1be
ez1ga
ēt1ki
us1tē
īn1ko
el1ze
ab1lī
ar1tā
aš1ķū
en1vi
il1fa
ik1ti
eg1ri
et1vā
us1mi
um1te
eb1jo
eļ1ģi
ar1ha
al1mi
ig1lā
ek1vē
is1le
eg1rē
el1tā
ap1ģe
iz1ri
er1to
ug1to
el1lo
ār1lū
el1sī
el1fī
oņ1da
in1du
eg1si
ub1ļo
un1zē
ar1bī
iz1ju
ap1nā
at1ce
ej1da
am1vī
eņ1ķi
oš1ļā
ij1me
ob1ra
e1dže
ap1pī
am1pi
īķ1ma
op1te
uz1cī
oņ1te
at1vā
ap1ņi
uk1lā
ir1so
ak1me
ip1lo
ik1ca
ap1fi
oj1ne
iz1pa
ok1to
ok1ci
en1mu
ip1nī
ol1za
ār1ģi
āk1ļu
ēr1to
āl1šā
ef1le
as1li
ar1so
as1mī
at1re
īs1co
ar1nā
ug1ta
is1ta
eg1ļu
ām1ni
ēg1ti
eļ1ri
o1dzi
op1lē
ip1nā
oš1ķē
ap1bū
im1nā
ir1gē
īg1vā
ēr1nu
āk1si
el1mo
iz1ņi
ap1mē
al1pa
ol1ti
un1vē
os1mī
āk1li
as1pā
ēr1ķu
ul1tī
ij1ti
im1fa
ūs1ni
um1ba
um1me
al1dā
us1to
iž1ce
it1cī
or1ņa
ad1rī
ur1ba
us1vā
u1dze
oš1da
ok1mī
ež1ģi
ef1li
ir1kā
uk1ti
uz1dā
ēr1ģe
īg1tē
ūs1te
is1vi
il1ti
eš1ļā
ik1me
or1de
od1va
ur1zi
iz1či
uk1nī
az1ma
uz1ja
āb1jo
at1fa
ev1ri
iz1jo
īs1pa
u1dža
od1ko
eb1ro
is1li
at1mu
at1sa
ub1ri
ab1me
ēļ1ni
ār1hu
ik1tu
ok1sa
em1dē
ab1lā
um1sa
og1lē
āg1ta
ez1li
ob1ļā
ad1pa
ig1na
or1sā
ir1da
an1sī
am1mu
ul1do
ār1či
uz1vi
ol1ho
em1zu
ut1ni
el1šo
uļ1vi
īk1šo
is1lē
uz1sa
ir1gī
ež1va
īb1ne
īd1la
it1vi
ēk1ve
is1sa
em1pe
ēj1sa
id1ra
ol1da
il1ca
uv1re
ār1tī
ar1bū
ap1mo
il1ža
a1dzu
ap1se
ub1lā
as1pī
er1tu
īc1ni
ip1ra
og1lo
ib1lu
el1na
uļ1ni
ak1si
an1ši
ēr1zi
er1ke
am1ka
on1za
ār1bē
ud1ni
ak1ha
us1mo
ār1ņe
at1dū
iz1žu
ām1ma
aj1mu
uz1čū
aņ1ģi
iz1ho
ēj1ni
ir1ni
ek1tu
ās1ku
el1žo
iz1ģe
ēr1ķi
ēr1se
īr1sē
iz1na
ob1ro
al1go
um1si
op1ļa
ur1tu
or1tā
ul1cē
iš1ķo
ad1ro
it1če
il1vi
uz1se
oh1lo
od1ne
iļ1ra
īg1no
ap1ni
oz1ni
il1me
ur1da
āt1do
ar1he
in1tū
ul1fī
us1gu
ul1cī
al1bā
ib1ra
ir1ga
ul1gu
ān1ri
il1gu
ab1pe
op1to
il1zi
is1ķi
uv1cī
ap1tā
až1re
iz1pī
ud1be
ek1ne
ab1ļa
iz1ki
ar1mā
iļ1ķe
ok1ro
ig1šu
at1bo
ār1pū
īb1ta
uz1kā
iz1bi
um1ma
or1ko
an1vā
es1le
is1ci
op1mē
ām1pu
ir1ba
os1tē
ig1rē
ok1da
īk1le
el1te
ek1ru
ok1mā
ob1ja
ar1gu
iz1ķi
or1gā
ij1jū
is1mā
ūk1nē
al1ce
ēs1tā
ur1la
īv1bē
ar1bo
až1vi
iz1li
om1fi
ar1ni
ār1cē
uņ1ni
ir1pā
uk1šu
in1fu
op1ļo
on1mē
ēš1la
ūm1ju
on1me
is1ja
āl1da
āj1pu
el1zi
ēr1ko
īs1tū
āb1ta
it1re
ēr1ta
ik1ne
aņ1ģē
es1na
uš1ķī
ēk1sū
āp1jo
ār1ja
op1li
ib1rē
oš1ķa
ag1ta
ob1jo
ok1lē
ul1ku
ip1te
ar1cī
ār1te
īg1ša
uz1ki
ās1la
et1ro
ās1ti
ar1ti
iz1sa
āk1zi
uz1sē
em1šo
ok1so
et1ze
ar1žī
oš1vi
ap1ri
ad1ru
u1dzo
āp1nē
at1za
ūr1li
iv1la
or1va
ūv1be
ep1ni
eņ1sā
ūr1vē
āz1tā
ēb1šo
ev1lū
ib1kā
īt1da
um1ša
ug1sa
ik1da
ak1lu
ēr1ļa
os1mu
īņ1la
if1rā
oņ1tū
eg1ne
is1mo
uz1šū
on1tū
ob1šo
in1va
eg1lū
ir1pi
u1dza
us1la
ūs1pu
ib1to
iz1sē
ap1čū
ok1lā
uv1mu
īk1sa
āķ1ve
iz1mu
uz1mī
uļ1ķo
ar1hī
ēl1me
īg1me
ag1ve
ur1vu
ār1ha
ed1ni
āt1se
at1ņa
at1sū
ūk1šu
ol1me
ūz1mē
ip1to
at1tī
ēs1ta
us1ve
iņ1pu
ol1va
in1ši
āp1ta
ar1ko
ēk1si
el1zī
er1nu
az1pi
ār1bī
uk1la
ek1ņi
er1ro
ēt1bi
al1da
is1pe
īk1mu
ēc1pu
in1dē
ūr1ve
es1tū
ēr1mi
ez1ko
ār1ko
āl1lē
ep1te
ār1re
an1ce
od1ku
ig1ru
īk1tu
ēž1ve
ap1no
ul1ga
el1ve
at1ņe
ār1pā
op1bu
iv1ti
iz1dā
ig1ra
ij1va
ēr1di
iz1lo
uz1bo
ās1nu
el1ņa
us1ne
ev1ge
ab1di
uz1jo
ār1kā
eb1re
ir1nu
op1tā
il1li
uz1pī
āj1do
ēg1tī
ul1re
eļ1ķī
ej1nī
av1ļu
aļ1ņu
ūs1ga
im1fo
ab1ta
ut1ne
iš1ķu
ez1nu
or1sē
ep1ļu
ūt1si
ik1le
is1ga
oz1to
op1ti
ur1šo
il1kā
im1du
ēr1ba
iz1no
ar1je
am1du
ul1lu
ot1ni
eš1si
at1pa
ab1to
ip1zā
ūs1tī
at1mū
ī1dza
im1bo
op1tu
ak1ta
es1ve
īk1ma
ūk1ša
in1di
uz1ži
iz1čī
ad1vi
am1šā
iņ1ņa
ār1ce
ēd1ma
ik1ni
ap1tī
ap1zu
ep1sī
am1pe
uz1lē
iņ1ģi
uņ1ķi
ur1pa
eb1ra
eš1me
āt1ni
or1me
uč1ka
ar1vi
en1gā
ar1ši
uz1la
es1kā
uk1ņī
ap1gā
er1vu
es1nā
ir1šo
iz1sī
at1gū
ar1ma
ef1ro
eš1ķi
on1nī
ap1ho
ez1zi
oņ1re
ur1nu
am1be
ek1no
is1jē
āž1ni
ag1lē
ek1ci
el1da
es1pi
ož1vī
oņ1mā
il1pā
ok1la
as1lī
en1ze
ām1vi
ir1be
ik1lī
e1dzo
uz1ti
ul1ta
ār1gu
an1so
ik1si
eņ1ze
iv1ju
ag1nā
ār1bi
ib1ša
or1fo
ūr1zā
ap1ņa
ap1ji
ēr1lī
u1dzu
en1rā
iņ1pa
at1ķī
ār1vā
ap1ļo
ār1ca
ek1šā
ēr1ka
īz1da
us1di
īk1to
op1sa
iv1ko
āb1ti
il1jo
iz1ra
ir1se
uļ1pa
iz1ņa
ār1fa
os1li
ez1ma
ar1si
oš1ta
eh1ro
až1di
er1sā
ep1sa
el1je
āt1ce
ek1lū
an1dā
ig1rā
is1za
ok1ru
eš1ļi
āj1mu
ot1rē
el1ka
ur1čū
eb1šu
uz1žū
eg1ve
uz1ņu
ob1ri
ap1bi
iž1ga
av1va
ūs1na
ēj1ra
iņ1ni
eg1tī
uš1pa
ag1ma
ur1ķē
on1go
ēr1ne
īž1ni
ir1ģe
as1kū
ēr1cī
el1ša
ēr1nī
āk1ti
es1mā
ap1dē
īn1me
ig1šo
es1ki
ot1ne
ab1rā
ab1te
ib1rī
ir1po
az1do
en1sī
az1nī
er1bo
al1bī
ib1lē
aš1ha
es1va
et1ru
ez1jē
id1ga
il1tē
on1ki
il1na
ur1go
oņ1pa
ur1lī
od1pi
īb1to
iņ1va
ad1ni
ev1ka
ar1la
āb1tu
at1vī
er1su
us1ku
iv1vē
iņ1za
or1nī
an1do
ūt1ne
om1bi
an1to
el1dē
uļ1sē
el1jē
il1ča
ās1lē
as1pu
uz1su
uš1ku
om1po
ul1bē
ēc1mē
eņ1ko
īv1zā
eg1le
is1ce
is1ni
od1rā
om1na
ul1mi
āk1ļo
ig1mu
ir1me
eg1ra
eb1ta
al1mu
is1ki
in1jo
īn1vi
ef1lā
ēj1ca
ar1hi
ul1ba
om1ja
an1kā
am1bū
op1tē
ol1lo
am1mā
at1ķi
ad1hē
ot1ma
em1lī
āl1le
as1mē
ūr1ga
ik1la
um1so
an1dī
us1lī
ūr1ta
in1že
ip1ri
ej1se
ul1ki
eg1bu
il1šo
at1pe
at1čā
ap1lē
eg1lā
īs1re
ēr1ve
ek1ca
ap1so
ēr1mo
āz1ta
or1tū
āk1šu
em1ci
ok1ne
ēd1nī
es1ti
il1pe
ip1na
ik1va
os1lī
iz1šā
od1ri
ob1rū
un1va
eb1ku
il1to
ir1tī
uk1ro
iz1cu
āž1ra
ur1di
eb1ju
ul1so
īs1lo
ēj1čū
in1fi
ur1za
il1va
iz1fa
al1do
ib1si
ēr1bā
os1ni
oš1re
im1ba
ig1si
ūr1fi
ec1pu
ak1to
el1so
ek1rā
īs1va
aš1mī
en1ti
en1pu
eb1ri
am1ma
es1me
ūn1vi
ak1ci
ēp1ša
eš1ni
el1vi
ov1ka
ēz1do
iz1lā
en1tū
en1su
ur1nā
ot1ro
ob1re
ep1žo
at1ķē
ēp1ti
en1ci
at1bē
uk1to
āg1šu
il1mē
ār1žo
is1va
ēt1ce
un1ro
eg1me
on1bū
ah1ro
ād1re
or1ni
uģ1ni
uz1so
uz1rū
īs1kā
īs1pu
ar1šu
ar1sā
el1bu
il1ta
ur1ķi
ak1ne
ap1vē
ār1ča
av1ve
os1pē
aļ1ra
eš1ķe
ur1zo
as1va
uk1či
ar1pi
uk1ra
ur1mē
ez1se
al1pī
um1za
īs1de
aļ1ru
uk1ko
eb1le
ul1ju
āt1ze
at1bū
ez1vi
at1šū
ag1ra
āt1kā
īs1te
iz1jū
eš1ņo
ur1co
ar1bi
ūs1tu
it1ka
en1sē
eš1ņa
ag1ro
aļ1si
id1ri
it1no
ež1ma
os1pi
ev1ti
ēk1pi
ap1tū
us1mī
el1hi
iz1ha
eš1ļu
ām1vā
un1gu
ā1dzī
āl1nī
eb1li
od1re
āk1la
ab1zi
af1ni
ād1ni
ig1ri
ek1ga
uļ1mu
on1va
īv1ko
um1ra
at1pā
ub1ļa
er1nī
ug1ļi
aš1ke
ēr1tī
ap1ba
od1jo
ok1ļū
us1tu
uz1ķe
ih1ta
iņ1ga
ēp1jo
un1ce
il1ši
īt1ne
oš1ķī
ig1ta
ol1lī
ūk1ga
es1pē
et1bo
ez1di
ap1ķi
uz1ca
ig1mā
or1ķa
ez1to
āp1ju
ēk1nī
at1ļu
es1sē
ir1pa
ap1ra
up1li
ul1dī
ē1dza
ek1so
ol1zī
ēr1co
or1ka
ad1ja
en1ra
ez1ba
iz1go
en1hā
ez1ka
et1re
ah1ve
il1pī
ep1lu
eg1ti
im1fā
ih1nī
ēr1dī
ap1čā
ēj1vi
an1tī
eņ1tu
ut1ru
ēj1tā
ur1bu
ur1de
es1no
am1pī
un1vā
iž1ku
uk1lu
un1bū
un1tu
is1nī
ub1ļi
ap1či
ūd1ri
en1lī
es1pā
iz1čū
ob1ji
ez1tā
em1žu
op1lī
ab1lu
od1rī
āj1sa
uk1ci
an1žē
ūt1ri
un1dē
eg1gā
ur1pū
il1di
iķ1ve
eņ1ka
an1tū
āv1vi
īt1ro
iz1ro
āl1di
i1dzi
ad1rā
ap1ne
at1va
iz1ma
ūv1ko
ūt1nē
až1va
ān1sa
uz1zi
as1vē
et1vē
iļ1bu
aš1vā
ap1ka
iz1pi
er1ša
ed1na
im1dē
ag1nē
āj1bu
ād1ve
eb1tā
us1pū
īt1sa
ap1ži
ūr1ni
og1ļa
āt1nē
el1vē
et1la
og1ru
iz1ka
al1sī
ir1zu
om1fo
eļ1jū
il1bī
il1sa
uņ1ģī
ej1sa
or1nē
am1ta
ul1šo
or1pē
em1du
ur1lo
at1be
ur1si
ēr1ti
er1šo
at1pi
or1lo
ev1na
ec1ri
ol1ba
iņ1kā
ār1hi
os1fā
at1lū
og1ni
aš1sa
eg1li
ij1de
eļ1mā
il1nsa
ir1pti
iz1šķo
ēl1mju
uz1glā
ap1slā
op1ska
ek1špē
al1tru
iz1smē
ēr1kta
us1kri
il1bsi
ul1gri
ap1sku
at1frē
is1pru
at1fri
um1pja
ār1brā
os1tga
as1pre
ār1sve
ūm1tve
ār1brī
uz1fra
iz1dru
ēr1ptu
un1dzā
ut1ska
īk1šķo
āb1sti
iz1hlo
ēr1šļo
ap1gro
at1šmī
un1spu
es1tro
ap1blē
et1rka
us1gri
at1plā
on1ste
ap1šķī
el1dze
ab1sce
at1kļa
iz1prā
ug1šde
on1fli
at1stu
im1šte
ir1kta
ar1bnī
er1dzī
en1dro
ok1snī
uk1šķa
eš1bļo
īt1ņmē
et1rde
ir1mbā
az1gru
in1grā
uk1ska
ap1spo
āg1sti
ug1špa
al1kva
ez1tne
an1gli
udz1ba
ūk1sli
at1sma
ap1fra
iķ1skā
uz1sma
īp1sla
il1stu
iz1gra
os1krē
am1sti
uz1pre
ez1gla
īdz1jū
us1trā
iz1pla
iļ1krā
ēr1zka
ap1pro
ir1sno
ir1smo
ir1mme
er1dze
ān1prā
ap1bru
ēg1sto
as1bra
ek1šne
ēr1bšo
edž1li
as1tru
un1dra
āl1pro
ār1grē
ēr1stā
ar1pta
īk1stu
ez1spē
am1skā
ir1kļo
on1gru
iz1šta
āļ1dzi
āl1štā
īs1pro
ur1dzu
ir1stī
ār1šļa
uz1gru
el1pšu
al1frī
ek1šga
ir1mdī
ek1sku
iz1spu
uz1plū
āk1sla
iz1dre
in1ssū
uz1gle
om1pre
ār1gti
udz1cī
iš1brū
uz1kru
uz1sli
uz1klā
at1ble
īdz1ni
iz1smī
ār1sni
īs1spa
iz1pre
īg1sko
iz1žva
ir1gti
ēr1bta
īt1pra
at1gla
as1dzi
ap1skū
uk1šķe
at1dzī
uz1šta
uk1lva
at1dzē
ār1šma
es1prā
iz1blo
al1sti
at1zvi
in1dzo
uz1krē
at1kvē
an1brū
ur1ksi
uz1stī
op1sta
in1sti
on1sti
uz1pli
at1kve
as1krē
in1sda
an1smi
ap1stu
us1tpu
uz1kņu
ār1blo
on1gli
ar1pli
ap1šļa
us1kre
āk1šķu
al1vja
iz1sni
ap1pla
uz1brā
iz1brē
eš1stū
iz1svā
ēr1kša
ug1sta
at1blo
ap1švi
il1dno
iz1glū
ir1sdi
im1pro
ār1tre
iz1bri
āl1bra
at1bri
uk1stē
iz1brū
at1plē
il1bšo
ur1dza
ik1lpa
āt1rra
uk1sti
ur1kša
en1džo
ār1svā
ap1krā
īk1šķi
at1rre
iņ1zva
at1žvī
ār1blī
ēr1sta
ār1smi
iz1šmī
ug1šna
iz1skā
uz1trī
ap1svī
is1prā
ek1sta
at1sla
at1trū
āk1slī
uz1kna
il1dvi
ār1dzi
uz1šņu
is1tre
iz1svi
ap1dri
el1dmē
ul1gto
an1tzi
is1kvī
uz1kļū
ār1šņo
uz1frē
ib1sto
ig1sta
in1ktī
ir1sni
en1sne
em1pjo
ēr1btu
īn1skā
ēk1šņo
ik1smē
es1trī
at1šķū
at1pla
in1gto
ot1rdi
al1cvi
um1bri
uz1švi
is1glī
an1džū
ap1sle
uz1pļē
ap1šķe
iz1ble
ap1šņa
ir1mre
en1tra
ār1tra
ul1snē
iz1spa
ep1sti
ūt1sga
āg1sto
īb1sta
ap1pļā
at1kle
il1gtu
iz1spi
am1tra
an1fra
uz1frā
ēr1nva
uz1stū
ūk1sto
at1šma
um1šzi
ug1stā
at1špa
il1kti
īp1sle
iz1tri
os1tro
el1pšo
av1sta
ak1tda
ik1snu
iz1stū
ok1tri
ap1gve
op1spē
iz1pra
el1ptā
es1tra
iz1kni
ān1spē
os1kva
ol1ste
ul1dzo
ek1šzo
uz1ste
uz1brī
in1skā
ār1švī
il1nvē
ūv1pro
iz1šļu
ev1ski
en1zda
āt1rda
ēk1šķu
ig1sto
ēr1kšu
ēr1ktā
iz1skū
an1kre
iz1pro
il1spi
al1kto
ok1zvē
ap1zva
ār1zvē
un1tni
ak1sti
as1tri
īb1spē
os1mve
en1sžu
el1nru
er1csa
uz1zvi
al1vtu
at1dzi
um1krū
ot1frī
ap1klī
an1sko
el1dko
an1tkā
ap1gla
īk1šņa
ār1gve
il1dba
es1tma
uz1sti
at1drū
ul1pto
uk1smi
as1trē
er1tro
īb1sti
id1spa
at1trā
ar1pna
at1sta
ek1trī
at1šņo
at1zve
ig1zda
ir1mpa
ak1tni
ir1kšo
ār1plo
ār1prā
il1nti
om1sva
ēr1bja
il1trā
al1kta
iz1dza
iz1šma
at1dza
iz1kri
ol1skā
en1tni
et1sti
at1tru
iz1špa
ur1kne
īg1zna
ul1sva
an1tza
ār1tņu
īn1krū
uz1šņo
ek1tkā
at1plū
il1kni
uz1žņa
ur1sli
iz1tre
ap1stī
or1dda
ur1gra
at1glā
ās1tni
uz1žmi
at1dze
āl1sti
ēr1slī
el1nze
āk1ste
op1pla
at1prā
up1sto
em1plā
ib1stī
up1sti
ār1špa
ēj1pla
ār1hlo
ap1frē
il1kto
al1dzi
on1tri
ar1gsē
iz1frē
ap1bro
ul1tne
im1stī
ug1špē
em1pta
at1grū
as1tma
īk1ste
iņ1krū
il1kšu
ek1ska
is1tvi
ār1dro
iz1tro
us1smē
el1zta
ēr1psi
āk1sme
ēs1tne
ār1grū
ok1gri
up1stē
ok1sko
et1rro
un1dze
ap1trī
uk1šķu
in1sri
en1tri
āj1dzī
ap1fri
et1rpa
uz1klu
ik1sme
ār1dra
iz1kvi
ēr1pto
at1plī
od1pra
at1glu
ap1fli
uz1gri
at1krī
īk1stē
oš1prā
an1frē
ap1sva
il1bta
ek1smē
ār1šru
us1tmā
īk1smī
al1dķi
os1trī
in1ssē
al1tga
ir1mkā
ap1zvi
ūg1sto
em1pli
uz1ble
on1spe
at1spā
ār1sko
ap1trā
ek1šli
āl1skā
iv1pro
ar1krē
iz1tra
uz1tri
uk1ste
ir1klī
ap1kna
er1spē
ik1šķa
ak1šķo
ur1gšo
al1dga
ap1kla
ap1svē
in1tri
im1tga
in1šķi
ēr1bka
ēr1sti
at1ska
āb1sle
ap1slī
iz1slā
an1gļu
ir1msā
ēr1pša
or1tlī
iz1dri
un1kta
el1dzī
em1ztu
en1ksi
ār1kna
un1kto
ap1klu
at1tra
at1brā
at1žva
an1kro
ap1sme
ūg1sti
ar1tmā
in1gti
ār1sti
ik1stē
om1bve
ap1sko
ār1ple
īk1smi
ug1sne
ap1krē
en1skā
en1szī
āk1sne
es1pre
ēr1ķti
āl1sma
īr1ska
at1slī
us1krē
us1ska
el1pta
en1kto
ar1bga
ār1tru
eņ1krū
en1trē
ār1spu
en1spu
al1ktā
ik1sti
em1zti
āt1stā
al1kci
ap1kļū
el1nsi
ēr1nru
ir1dza
ār1klī
at1tre
il1dma
īk1pla
ap1sni
el1kme
el1nbā
ak1smē
āb1sto
un1drā
uz1glu
uz1ska
en1slī
an1sli
ēr1sba
un1dro
el1zto
uz1trā
uz1spā
ap1dzē
ap1dru
in1dze
ed1gri
eļ1blā
an1kci
os1krū
iz1spā
an1krū
ir1sra
it1sko
ir1mso
un1ktī
iz1slī
er1zto
et1pra
ur1tra
al1tme
iz1slu
il1gti
iz1gre
ek1šķī
op1sva
uz1tru
ar1ppa
in1dzē
ab1dzi
ur1tni
uz1bri
ab1stu
in1gra
uz1sva
iz1krē
ap1dzi
ug1šte
um1bru
at1dro
ir1sti
ur1sti
āl1sko
at1klu
en1kšo
ut1skā
il1pšu
ur1gšu
ar1knā
ap1knu
im1bra
ēk1stu
iz1knā
il1bto
āp1sli
us1tru
ak1šņo
ap1prā
ir1dzo
en1krā
ār1spē
ar1kro
iz1dro
ār1bra
il1dnī
el1dba
al1bri
uz1brē
ot1gri
at1tvē
ur1sme
uz1šļa
ek1šte
at1šņa
en1sro
āk1slo
an1žsa
uz1plī
an1tra
il1bša
il1tni
us1glā
ur1gti
īg1stu
ar1zva
ol1lmē
iz1kve
ar1glī
in1kru
ap1kņu
ir1pšu
ec1skā
ar1dzi
od1ršu
al1tma
uz1sle
eg1spa
ap1šļi
ek1šķo
uz1spo
ar1kto
iz1zvi
uz1šķo
il1trē
or1tre
im1šļa
iz1blē
el1gti
uz1slē
ār1spo
al1dka
uz1bre
is1tzo
im1fva
az1pra
ap1plī
aš1kri
ir1pji
uz1šļu
iz1sla
em1zto
ur1kri
al1tna
er1dzi
en1kti
at1pļē
ēr1slo
ar1gto
ūk1šķi
in1dzu
es1pļa
oņ1pri
uz1bļā
us1tro
ij1skā
ār1fra
iz1tru
og1dzi
ij1spe
ij1stū
uk1šķi
ār1trā
uz1kla
ek1sče
ik1stu
ar1ppi
iz1šņu
oņ1sli
il1psi
iz1gro
ēg1stu
uz1sku
ol1stī
ur1vci
uz1smī
ur1zma
en1sve
er1spe
uš1plē
ur1bšu
at1stū
iz1sme
el1gšu
ec1sta
ap1kra
ek1šda
il1dde
el1kņa
il1dle
el1psi
ap1stū
ap1ple
uz1ple
ur1kšo
ār1dnī
ēr1pju
ēk1šķa
ir1mte
ug1ļķe
an1kvē
il1gta
īr1šķi
ap1svā
ul1lpu
es1nvē
uz1gve
at1pri
ug1šda
at1šķo
iz1plī
ār1bri
al1dkā
udz1ma
un1ssa
os1prū
iļ1ņve
er1che
ān1skā
ab1ska
ēr1sli
ār1krī
al1kšu
ur1sto
ūg1sna
uk1sto
ir1mcē
id1sta
id1slā
ut1sko
ir1stā
ār1pro
ir1kti
ār1kre
ap1glu
as1tne
iz1švī
uz1spu
al1nrū
ār1spa
un1ktā
āb1slī
ār1pļē
ir1bju
ur1bto
el1svi
un1ktū
ug1šga
ir1sli
uz1fri
ur1bta
āb1stu
em1brā
om1pro
ez1glā
ep1sto
al1kme
iz1blī
ar1ksi
īk1smo
ār1spe
ap1krī
iz1šķē
ur1tkā
ēk1lko
ār1tna
il1dsa
al1dni
el1dce
on1tru
iz1sto
ūp1sto
ap1žvī
ap1tri
od1gru
ār1gtā
iz1gve
el1gsi
er1nha
at1švī
ār1hro
il1tvā
uz1sme
at1sve
im1tni
uz1pri
ēr1sra
as1krā
en1ska
iz1glī
us1tdē
ol1tme
ūr1stu
um1švi
at1šļa
ār1knā
uz1tre
ok1šņo
at1bli
at1sni
el1gto
ek1šķe
ab1sti
un1fte
ap1gri
ir1ste
ul1sni
en1tvi
am1plu
am1zda
ik1stī
at1knā
at1skū
is1tro
is1trē
īg1sta
ir1spu
am1svē
ār1bru
ec1stū
ul1dza
il1kšo
ār1plā
os1tni
īk1sna
uz1sta
ār1zda
ār1šķi
uz1bli
ek1tro
ap1grē
ur1bšo
ir1slē
iz1kla
uz1trū
uz1tra
ak1sto
os1tre
uz1dri
ir1sma
ak1šķē
ak1tli
ek1švē
ās1nku
el1zti
er1cba
ēr1kto
in1dsē
al1kša
um1tra
ip1sna
eļ1ska
ār1šķī
ap1kri
ār1šķē
el1drē
im1pli
uļ1dzi
ir1pta
ēr1pta
il1pra
up1stī
iz1fra
us1tre
ub1krē
ār1pļā
in1fra
il1kta
ir1mpi
ap1šņo
at1sku
un1dzi
es1trē
an1drī
il1pto
adz1ni
ar1pju
in1gtā
iz1gru
ap1šķo
ēr1skā
ot1rpi
or1tfe
ir1mti
ik1šķi
an1tmē
am1bri
un1dža
il1pšo
as1brā
el1gšo
ap1kvi
ug1sme
il1pne
ēt1svi
ir1kša
as1sko
ek1spe
en1kša
iz1bre
em1pti
ār1gre
iz1frā
iv1stā
ul1šņa
ār1kro
as1pra
il1ktā
at1sle
iz1glu
ik1snā
ok1šņa
um1šma
ār1gru
ār1sme
at1sna
ur1kto
ik1sna
uz1svī
us1slo
am1pda
em1ztā
uz1žva
is1smi
ēr1tnī
ār1gtu
ār1drū
īg1sti
ap1tro
at1sme
iz1plē
ir1tni
ak1šžo
il1sku
ul1bša
um1spo
āk1sli
ap1blo
ār1dze
ār1kva
uk1sne
āt1rvi
ap1žva
am1stu
an1dra
ār1gšo
ek1stē
ār1slo
ār1gto
ek1ļve
ek1spo
ār1tsa
iz1dži
ar1blā
ēg1sti
ar1bdi
uk1šķī
il1bšu
or1pro
ap1hlo
iz1trī
as1trī
uz1smē
ār1spā
is1tri
ab1klā
uz1hlo
uļ1sti
at1fli
ut1nko
iv1krā
ur1tdi
ap1glū
ār1glū
om1skā
at1sto
um1sta
ap1gle
al1sma
el1tra
er1sto
el1dvi
iz1fri
et1sko
at1tva
ār1kle
āš1kru
er1tce
ap1kru
us1tri
uz1gla
ap1ble
il1sta
ap1sve
iz1dzī
as1tpa
em1psi
iz1tvē
ac1grī
ēr1dzī
ul1lci
iz1šļi
at1žņa
ov1smē
as1ska
en1tge
at1plu
īs1šķi
ār1dzī
ēk1šņā
el1nko
ār1sku
āv1sti
āl1dzi
ēp1stu
īv1kla
im1tmu
os1pro
ap1spē
um1brā
ul1dzi
ār1stā
ur1knē
er1trū
el1nba
ār1bro
ar1sme
ok1sne
il1ška
at1svē
ar1vde
at1slu
iz1bro
ēr1ste
āb1sli
us1skā
at1grā
āp1stu
ār1brū
am1stī
as1tmē
iz1kņu
en1kla
iļ1sli
um1sto
ap1bļā
uz1sna
ol1klo
er1tme
iz1fli
al1stu
ap1špa
ar1sti
āk1šķi
ār1dži
um1bra
ir1dzu
al1kjū
ap1smī
āb1sta
iz1kļa
ul1ptū
ap1smē
ār1tnī
ar1gva
udz1so
us1stu
ap1ste
ul1zna
ār1glā
ār1blā
ur1ska
il1stā
el1nra
ak1tri
at1kņu
eg1sme
ap1grū
ēk1šķo
in1spi
ik1sta
am1bli
ir1dzē
ēr1ktu
ur1kni
el1tni
iņ1krā
iņ1kre
iz1kle
an1spa
un1ska
am1stā
ēr1pšo
ār1fli
ir1mri
ēr1btā
at1svi
ir1spa
ār1tnā
ap1šķū
en1drā
ek1šni
at1trī
ar1kti
iz1pri
ig1znē
on1spi
ul1kve
ek1šķu
āt1sko
ek1sne
īs1krā
iz1klā
ēj1tve
ur1kti
og1ļhi
or1tme
aš1plū
ēj1slē
am1pla
ēs1tni
ur1bsi
is1tka
is1dzi
iz1spe
ab1sta
āp1sti
as1tme
os1tri
udz1da
ur1dzē
at1šļu
at1bra
un1kla
er1zti
uz1pļā
ār1dre
il1gša
iz1ple
iz1žņa
er1ztā
el1dše
ir1knē
eņ1krā
ēr1ssi
al1sno
ūp1stī
ir1gsi
iz1sta
ir1sse
uz1spe
ek1sni
īg1snē
in1dzi
at1kli
ar1bve
on1glo
iv1ska
il1dni
ār1kra
ār1blē
ar1stā
ār1sli
eņ1ķmē
ēr1bsi
ik1smī
āl1sci
at1dre
až1brī
iz1plā
ir1mve
uz1gro
up1jma
uz1dza
em1pto
an1kto
ež1sta
ēr1šļu
ap1brī
uz1kro
uz1skū
uz1krī
ap1šmī
uz1kvi
il1btā
or1tje
es1krā
at1tve
ul1stu
ūk1stu
en1kta
ēr1stu
ar1bma
uk1stu
ēr1nzi
uz1slī
ūk1sti
at1sva
ap1pļē
il1nmi
ir1snī
in1dni
āj1prā
ar1sbu
at1spa
el1nma
ek1stu
is1grū
is1nle
āk1stī
uz1stu
if1šte
ār1spi
īk1stā
ar1ktu
ur1ktā
āj1dzi
ēr1bto
iz1zva
at1knu
at1fra
en1sra
al1ctī
ār1bre
ar1bni
ār1tni
ez1pro
an1tnī
ēp1sti
as1trā
āp1sto
īr1sva
iz1šķa
ig1stu
er1tra
es1tru
as1grā
al1sna
ur1pre
ur1mjā
ēn1prā
at1pro
ek1ļpa
ik1lve
ēr1kšo
iz1gla
ap1sna
in1dza
ār1gra
ir1gto
iz1sna
an1čki
ap1tva
ār1sna
um1špe
at1zva
ig1zdo
en1sva
et1rga
il1gga
īk1sme
al1stā
et1rri
iz1dzi
ār1pra
iz1trū
ār1pli
ēk1šķē
āj1sta
iz1kro
ur1kšu
iž1knā
or1bci
em1ptā
an1scē
ir1kšu
al1tdi
ēk1šņu
īdz1ši
ot1rre
āt1spē
ēk1mju
āt1krū
il1dda
at1svī
udz1kā
ār1trī
ar1ktā
āl1ska
en1sli
es1pri
ur1btu
ug1stī
uz1plā
em1zta
iz1bļā
īk1sti
uz1spa
ār1tve
an1dce
el1dse
uz1kra
ap1sli
ir1gta
uz1slā
ir1kli
oņ1plū
ur1gto
an1grē
ūk1sna
āv1zva
an1slā
ek1švā
ār1žva
ār1šļu
ap1frā
až1skā
at1pre
as1tti
iv1plā
uz1grē
ek1šno
iz1grā
uz1bra
es1tpa
ur1bra
iz1kļu
im1sto
ur1gtu
om1dzi
ir1gka
iz1šķe
ek1sti
uk1šga
ār1sma
el1tka
ar1gma
al1nra
uļ1krē
ar1gka
iz1svē
ēr1sto
il1špa
im1tci
uk1plē
el1pti
is1dra
er1sme
ul1snī
ār1krā
āt1sma
ir1stu
at1pļā
uk1smu
an1dtā
en1kšu
ar1sko
ēr1pti
ēk1lva
or1skā
uk1sta
ep1sta
ār1tri
ir1kņi
ul1stā
et1rvi
il1btu
ār1sla
at1pli
el1nsa
ur1kmē
uz1bro
al1dne
ār1frē
un1spū
ek1šķē
en1pro
an1dro
at1bru
ak1snī
uz1tvē
ik1spā
uz1blī
ap1šķi
el1dra
un1svi
at1spu
ār1fri
ep1stu
ēr1szā
īb1sto
ār1dza
ār1gli
el1kne
ār1tne
un1prā
ap1kve
uz1kni
ap1dra
ār1gša
ār1kvi
ir1zga
ek1šgā
ek1sve
at1gle
ār1stī
es1pro
al1kma
iz1klī
ug1sto
az1pro
āj1sla
en1tne
ul1sti
at1kre
ār1sva
ār1šķe
iz1kļū
ap1slu
il1zka
ek1šme
am1pšo
ūr1sko
uz1grā
es1grā
ap1šņu
ir1kļa
ur1lmē
el1dfē
az1dru
at1rpu
um1stu
es1grī
iz1kna
as1smē
ur1spī
eņ1skā
ār1slē
udz1vī
un1dru
ar1ska
eņ1tra
am1pli
uz1kli
ul1gtu
ēk1brū
us1dzī
ap1stā
ar1kšu
es1kra
iz1brā
ir1sta
ar1gce
em1ptu
ur1ste
ār1dru
uz1pļa
at1glū
ad1skā
ov1skā
ak1stā
ēr1zga
ir1mga
in1gtu
īdz1te
ār1drī
am1bra
īk1šķu
ur1gsi
ab1sci
on1dri
il1pju
āp1jve
ar1gbū
ul1gšu
ār1dva
ār1tno
ap1plo
as1tka
il1gšo
iz1ska
ār1dni
ap1dva
īk1snā
ap1blā
as1pļa
ap1kre
al1pre
em1pšo
ap1tru
ak1stī
el1sku
ak1ņve
ak1špa
aļ1ska
ūr1sta
at1bļā
in1gve
at1hlo
ig1frī
ok1snē
ār1gri
ak1šķi
āt1sna
ul1tsi
as1tni
ir1sto
an1sfo
ek1šla
ul1tzo
ob1spi
os1pri
el1bri
ār1žvī
at1blī
ot1rti
il1gsi
uz1zvē
in1spe
ir1ptu
ag1sva
iz1kli
ok1sni
el1gra
um1spē
ūp1sti
ak1stē
ur1kta
an1dri
ir1pto
iz1pli
īv1drē
ar1pzo
ur1bti
ul1šņi
at1blē
og1ļra
iz1sle
il1pro
il1gto
eļ1tra
iz1slē
ār1kve
ur1btā
ār1frā
al1tla
ur1pmā
ēr1ksi
al1ksi
ir1kņo
in1sra
em1blē
ib1sta
in1sci
ur1ktu
iz1šķū
an1tni
ām1glā
ur1zva
īk1šķē
up1rla
il1nga
il1gla
ēk1šņa
en1prā
uk1špa
at1pļa
iz1šķī
ār1gšu
ir1gša
ul1dzē
an1kku
ul1tni
un1dzē
ap1sma
er1sti
el1ztu
ir1gko
im1tre
us1sna
ūk1šķu
ik1tni
at1brē
as1kra
an1dža
am1plī
ar1kša
ap1spe
an1ska
ih1svē
od1sli
ēr1pšu
ar1gre
am1sto
ān1ska
or1tvī
at1svā
uz1šķū
ūr1sto
in1sce
ud1spi
udz1ga
al1snā
āg1stu
al1tro
at1šta
at1kļū
udz1vi
ap1slo
ap1gre
iz1šņo
ug1stu
im1sti
up1stu
ur1stī
os1kra
ir1ska
og1ļde
um1dzi
in1kvi
ed1kļū
ul1tra
iz1sko
el1gtā
ur1gtā
iz1pļē
ap1smu
er1stī
āt1ršu
ok1šņu
ap1šķa
āt1dzī
at1tro
at1brī
al1sta
udz1ru
ar1gtē
in1sta
iņ1ķve
at1kri
al1snu
iz1zvē
iz1klu
in1hro
ir1ptā
as1kvi
ur1spi
iz1kvē
ār1skā
ir1gtu
āp1sta
uz1bru
ed1krā
et1sta
al1vga
am1pša
ar1pga
uz1sla
at1šķī
at1dži
ār1kļū
ār1šro
eņ1bra
īk1gru
ār1klā
ak1ņko
od1prā
at1klī
iz1stē
ār1žņa
at1tri
ik1stū
ek1šzī
ār1kni
ār1pre
ap1klā
ul1gta
ēr1pjo
ār1gsi
iz1šņa
iz1gle
ēr1bjo
is1stū
eļ1drā
ik1ste
ēr1nga
ap1tve
uz1skā
ap1knā
ik1snī
am1ble
ek1stā
ol1fga
em1bri
uz1spī
el1dma
iz1slo
ar1gkā
iz1svī
ūg1kri
un1kti
er1pre
uz1švī
ap1dzī
iz1spī
ek1tda
ēr1dze
il1ska
ār1tnu
ur1bša
ap1tra
ap1dze
an1ste
in1ktū
er1ztu
as1pru
en1sca
uz1svā
il1dmē
ik1sni
ār1brē
āk1sto
āk1slu
ap1bri
ap1stē
iz1sti
ap1pļa
ār1šta
īk1sne
un1tra
ok1šķi
ūs1tni
ok1trī
iz1glā
om1ple
ār1kri
uv1bra
īv1stu
āt1rgā
ār1pļa
uz1klī
uz1slo
at1gre
eļ1bri
as1prā
ig1žņa
ēr1glē
ūr1sti
īv1sva
ah1tve
ūk1sne
et1rsi
uz1špa
an1dze
um1pra
er1plē
iņ1sti
at1drī
at1dva
in1tnī
in1gvi
al1šķī
ap1slē
id1plē
il1nva
uz1glū
iz1švi
udz1pu
or1tli
in1kri
ap1pri
em1dvi
ār1drā
as1tro
ar1dze
āk1sni
uz1ski
as1tva
um1sve
ār1gdi
ik1sto
os1pre
at1frā
el1dre
il1dva
ug1prā
ul1stī
uz1svi
ur1tda
ār1slu
ūp1stā
ez1glu
īļ1knā
an1cle
ūp1stu
ec1svi
ak1šķe
ir1dzī
uz1dze
āl1spē
ij1dro
ār1kla
im1sli
ap1bli
il1sru
on1skā
uz1spi
ul1dze
ik1šķo
us1krū
ek1stī
ek1šro
it1bri
as1pri
ik1šķu
or1tku
at1kni
is1mju
im1stu
ez1prā
at1sli
ur1vma
om1sta
er1sta
ot1rpu
es1pra
uz1gre
at1šķē
ur1dzi
ūk1ste
ap1smi
ār1stu
an1skā
ūr1stē
ur1zmi
ār1krē
er1sma
at1šņu
od1sko
im1pre
al1snē
ap1dza
iz1pļa
il1krū
at1spe
uz1krā
in1tra
at1šķi
at1bro
el1tga
in1tro
on1tda
ak1šķa
as1tna
ir1ski
aļ1stu
os1kni
ēr1tni
ār1trū
er1zta
ir1zma
iz1knu
ar1gku
eļ1gle
iz1dzē
ap1sti
os1trā
uz1šķi
os1tru
ir1kļu
es1brā
ar1sto
ap1grā
us1tme
iz1ski
in1sva
um1sko
un1kni
at1kvi
uk1stī
ap1pli
ot1plā
et1rmo
el1djo
ub1sta
uz1sni
iz1dze
ul1gšo
am1pjo
uz1dre
ar1pni
is1mmī
al1dzī
iz1žvī
ar1bmū
at1spo
al1šķi
uz1kvē
al1kti
udz1re
ār1spī
iz1kra
et1rre
ab1sto
uz1slu
ār1plē
us1ttē
ur1sta
iz1gri
ot1rto
en1sti
āv1grū
ār1tva
un1slī
on1gre
ēk1sne
ir1kni
el1dpū
av1grī
or1tjē
īk1smā
īdz1ju
es1smē
iz1spo
iz1brī
um1bve
is1kva
īg1ļla
īs1stū
im1tkā
ār1gme
ār1ble
āč1plē
ēr1zci
ēp1sta
el1drā
ak1šķu
al1nga
uk1šķē
ir1ktā
od1ska
īk1sto
ir1spe
ir1pšo
ēj1spē
at1hro
id1smi
on1tra
at1gve
il1dķe
in1sku
el1dtī
ek1šķi
uz1kre
ap1zvē
ār1ska
ān1sve
udz1vā
iz1ste
uz1pla
an1cka
ež1frē
in1gša
ap1hro
in1gtī
ir1mdi
ir1mva
ap1svi
uz1dzī
uz1pro
ēr1sna
ap1dro
uz1blo
al1tva
ek1šsē
udz1ve
ih1stā
uz1gra
ēd1dzi
ar1psi
ār1dri
at1klā
iz1tve
ār1sle
ul1gša
al1tvī
ēr1ļve
ir1mzi
at1dra
os1pļa
ir1kto
el1nga
ēl1spi
ap1gru
ēr1bti
us1pli
ik1sma
ār1slī
ol1ska
īt1ska
ap1dži
ur1tnī
uz1dzi
ār1šmī
odz1ni
ar1gda
at1ski
uz1dzē
el1tli
ov1ski
el1ztā
at1blā
ar1dzī
is1trā
as1tra
en1svī
on1krē
ur1gta
en1tmē
ār1kru
un1dri
ār1gla
el1pva
as1pro
is1pri
iz1plū
il1dko
ār1šļi
ar1tne
us1tne
at1kna
at1kra
at1spi
ēr1ptā
īk1sta
in1grī
ed1spi
op1stu
um1šsa
ap1pre
ap1trū
ār1šķa
at1brū
um1šķi
el1stu
al1sto
uz1kļa
al1nze
at1gru
on1fro
at1kla
ap1brū
ir1mtē
īdz1nā
uz1šmī
ap1gra
ak1šze
ap1blī
an1kno
il1skā
ir1ktu
ēt1spē
al1vni
ar1gri
uz1kle
ul1sto
es1krū
iz1pļā
uz1plo
at1šļi
ug1šma
ec1sla
īg1sto
uz1blē
ib1sti
en1sto
in1kli
ir1dzi
ug1zna
in1gro
as1prū
ež1gra
iz1kre
eg1slā
ām1grā
ig1znā
am1fle
ir1pša
eg1smi
uz1šķa
ap1šķē
ug1sti
al1ste
al1nci
em1mvi
īdz1ti
ik1sno
ār1svē
et1rkā
ul1gtā
at1spē
ār1sto
il1šmā
et1rti
ar1dzē
er1cko
ar1sta
ēr1bša
āj1gle
am1pja
uz1dva
ot1rkā
ak1šma
uz1plē
ak1špu
ār1bļā
ir1gtā
ik1šķē
uz1zva
al1stī
os1kle
ār1ste
ug1šžo
ēr1tne
iz1dva
is1tru
ek1šku
ap1skā
ar1gti
ar1gvi
uz1smi
im1pto
ār1ski
ār1plū
uļ1ska
ib1snī
iz1šķi
ap1ski
un1sbī
ep1stē
us1sko
at1zvē
at1sti
el1dzo
īk1smē
an1sku
um1sla
uz1šma
ap1žņa
ek1šze
uz1kri
ir1mmā
an1čka
ēg1sta
at1kro
et1rrā
uz1knā
uz1stā
ap1drī
ez1glo
at1ple
ar1šļa
ug1šņu
ār1kli
ot1rzi
al1kvī
is1tra
ib1stā
or1dni
el1dpa
in1gpo
ul1sla
uz1tve
el1tta
ap1plē
uz1šņa
ār1sta
os1tbi
ār1gle
og1ļrū
er1stu
iz1plo
ūv1bri
ēl1spu
iz1sli
ap1plu
um1sti
uk1švā
us1tra
uz1dži
ēr1npa
el1pjo
et1kre
āb1slē
ik1lķe
an1spo
im1tku
ok1gre
iļ1ska
an1tku
an1sjē
il1pša
ūk1snā
āl1szā
ol1sto
us1trē
ij1krē
an1flo
ap1glā
āl1svi
at1slo
ur1bjo
el1sme
at1smē
op1dzī
ūg1stu
al1tra
er1tne
at1švi
os1trē
ez1drā
ur1gša
en1spo
ov1ska
il1ktu
es1tre
iz1dve
ār1smē
at1gra
āg1sta
ūv1gri
as1tmā
in1flā
oņ1stū
ār1klu
el1tne
ak1sta
ār1dko
ār1kvē
an1tro
at1kru
ap1sto
il1pta
edz1ni
is1pro
īr1gro
udz1si
em1bra
ār1zko
ul1šņā
us1sti
ēk1šķi
udz1vē
um1tni
ar1stu
ap1kle
īk1smu
up1sta
īk1sma
ār1zva
ab1rka
ēdz1ni
āb1stā
ēr1kli
en1tro
ār1plī
il1gšu
ap1kvē
as1tre
ak1ste
ek1šķa
āt1rmo
an1sce
in1sde
iz1kru
ap1šļā
at1bre
on1sta
ēr1zla
el1gša
ām1bra
el1dzi
uz1dru
udz1di
ap1brā
ar1kta
eņ1sla
ar1švi
iz1smi
ir1vja
en1gri
ar1kšo
uz1drī
ul1sta
ek1sme
ār1šņa
ār1zni
ār1tro
ap1kli
ār1svi
ēr1stē
īk1stī
et1rtū
īdz1ci
ur1tli
ek1sto
im1tsa
us1brā
uk1šķo
ir1zta
ār1stū
un1ktu
ēr1mju
īk1šķa
ur1kli
uz1fli
ap1plū
il1dzi
ap1dre
az1sva
ug1ļla
at1stī
iz1plu
uz1tro
is1sli
iž1skā
ir1gšo
en1ktā
ār1gta
iz1bli
ār1smī
im1brī
ār1dzē
ār1svī
ek1spa
īdz1ko
uz1svē
at1plo
or1tla
ab1prā
ir1tne
ūk1slā
iz1sve
et1plā
ir1sva
il1bti
uz1brū
īt1spē
uz1šķē
udz1no
at1slā
iz1blā
es1tdi
us1zvi
is1kri
ēl1slē
ob1sku
ēk1šņi
ul1šņu
on1tro
il1stī
iz1bra
ur1pni
al1dsē
im1ttū
is1spē
es1tme
in1gvī
ug1špu
ir1dne
iļ1ņla
ap1sta
ik1smi
ad1grā
iz1spē
il1gtā
iz1sva
il1nbā
im1stā
ak1šve
uz1pra
uz1grū
ār1skū
iz1bru
us1tsē
ug1snē
ār1dzo
in1tni
ig1sti
er1gtu
en1tru
as1krū
ār1slā
ap1tvē
el1sti
il1sto
il1dra
ot1rga
ur1kņu
ap1bra
er1tzā
at1stā
er1cli
ēr1bšu
uz1stē
ap1plā
an1gvi
uz1šļi
uz1blā
ed1rvi
as1tla
iz1stu
ot1spē
us1pro
im1tda
am1krē
op1pro
ig1žņo
at1bļa
ap1kni
iz1sma
iz1grū
an1dpu
īv1prā
ur1stu
ar1stī
ig1zne
ūk1sta
āj1sko
ek1ška
ub1sti
ur1dze
iz1hro
ap1šma
ap1spa
ār1stē
ib1stu
at1smī
im1sta
il1ksi
ar1ndo
on1kre
es1krē
āl1plā
uk1sma
in1gri
um1pro
uz1dra
ār1pla
ār1plu
at1ste
el1gta
en1gru
il1tze
ār1pri
iz1krī
at1krē
es1prū
is1svē
ār1švi
ār1knu
en1ktu
ap1tre
iz1kņū
ul1gsi
in1dri
iz1drī
ek1ste
aļ1ķne
uz1spē
os1tma
ug1sni
at1grē
al1sni
ur1nga
ip1frū
ēr1sko
at1stē
ēr1gli
ol1fra
at1gro
un1kci
ār1kņu
iz1sku
ek1sce
ap1sla
at1slē
ap1šta
ap1šļu
es1tri
uz1plu
ār1bli
ār1grā
uz1sto
il1tra
in1gru
ūk1sni
en1szā
os1prā
āp1jvī
ār1tnē
il1ptu
um1šza
is1kre
is1krē
ul1gti
um1dzī
ek1špu
ur1zni
uz1dro
us1tve
ās1trā
ūg1sta
ap1brē
er1vje
iz1grē
ar1gmu
at1dru
ap1kļa
ap1spi
ap1bre
el1pto
ār1tvē
al1kšo
uk1sme
el1dzē
il1kme
ēn1skā
ir1gšu
il1sti
ir1dsa
ir1slī
at1smi
ār1šķo
ar1spa
al1dse
uz1knu
ar1gpo
iz1šļa
at1šķa
ār1šņu
uz1sve
an1stē
ek1trā
ār1glu
ur1vju
oņ1sti
at1drā
iļ1pro
iz1tva
iz1trā
ap1spā
om1pli
ak1stu
ap1spu
ek1tdi
ok1ste
er1gra
am1bre
uz1bļa
us1gra
el1gru
am1sta
at1sko
īb1stu
ek1tri
el1mla
an1sve
at1skā
un1dzī
īk1gra
ap1ska
in1dko
al1ktu
ul1dzu
es1trā
at1spī
ol1dla
at1šķe
eņ1ple
os1tla
ik1stā
ap1švī
uz1prā
ap1kro
ūt1smē
is1gri
em1pšu
iz1bļa
ir1mno
ap1spī
ēr1kti
al1gme
ed1svi
is1bri
un1sne
en1svi
uz1kve
ār1gro
er1stā
uz1šķe
eļ1krū
od1rpa
īv1grā
et1rba
un1sku
ār1tmē
āb1stī
il1pjo
iz1stā
uz1žvī
uz1šķī
is1tko
os1pra
el1gtu
ad1smi
om1kra
ut1sva
il1pti
ug1pre
un1kte
il1gru
ār1šķū
ez1gli
iv1spē
er1dlo
āt1ršā
ēj1grā
ur1dzo
en1trā
ap1bļa
ēr1tņu
em1dni
in1ksa
āl1šķē
uz1hro
iv1sto
et1rjū
uļ1glu
ir1psi
el1zce
um1slē
at1gri
el1ptu
uk1stā
at1pra
ar1gjo
uz1tva
uz1sko
iz1stī
el1sto
ap1pra
ov1sku
ar1šru
ēp1sto
at1krā
ir1ksi
ok1šķe
iz1šļā
iz1dra
il1ptā
il1dsē
in1gta
ūp1sta
ug1ļko
ar1džu
iz1krā
ul1dzī
ur1stā
ārg1sti
ilg1sto
akt1spo
alt1gva
ark1sta
ugs1tlē
uzs1pļa
ald1skā
ins1grē
izs1prū
ilk1tni
urb1sti
ezg1lve
arp1pro
irk1sni
eld1plē
ird1spu
ilp1stu
īns1trā
ārs1kra
ird1smi
eln1svā
irp1sti
ārg1stu
ens1sta
ugš1sti
irk1sti
ilg1sta
als1tpu
ārd1dzi
irm1dzi
abs1tra
umš1brū
arb1spē
ils1blī
urs1krū
izs1pra
urb1stu
udz1šķa
uzs1kra
aps1pre
ins1gru
ens1bla
ārs1pra
arg1krā
ilk1tne
ens1tru
ulk1ste
upj1gra
unk1šķi
urk1sta
aps1krē
irs1drē
ērt1sli
obs1tru
ērt1ssū
ast1sko
ird1ska
irg1sto
ord1zni
aks1tve
ikt1stē
uzs1pre
izs1pro
ilt1stē
uzs1prā
eks1tko
alk1stī
īdz1pro
ens1dro
irg1stu
ing1sto
izs1kra
ink1stē
alk1šķi
ātr1sli
ild1spa
āls1tre
alk1sto
ubs1trā
aps1tru
ērk1šķa
izs1trī
ats1krē
ārs1trī
alk1stu
uss1kri
izs1pre
ent1lme
irg1zda
ilb1sti
eks1tre
aps1pra
ilk1sti
unt1szi
uzs1pro
eks1klu
iss1pri
aps1trī
ulb1sto
urk1sti
aps1pro
aht1klu
āls1sta
ens1krā
ilt1smā
eks1pre
uzs1tru
aps1prā
etr1kla
uzs1pri
īks1tmē
eld1spē
apj1dra
ist1hre
ids1krē
irs1plā
irs1stu
unk1stē
ilk1sni
ink1šķi
ird1smī
irs1kre
īdz1ska
alk1snā
īks1tsi
izs1tru
ars1tda
unt1sno
ēst1gri
uzs1tre
urk1sto
uns1dro
ulg1sto
ātr1spi
ilg1spē
erc1sko
ilb1sto
āls1skā
ens1krū
aps1tri
ilk1tnē
udr1skā
urb1jma
ats1pra
ird1sli
izs1trā
ekš1ņnī
ind1sta
aps1kra
ērk1stu
iln1bri
uzs1pra
udz1pla
ilb1stu
izs1kri
ilk1stu
irp1sta
eks1trē
ugs1tka
ult1zva
ātr1gri
ink1šķo
urk1šķa
ulb1sti
uzs1trā
aps1trā
irk1stī
ulb1stu
unk1tsi
ons1trē
īgt1spē
ark1stu
ilk1sto
ark1šķo
alt1kvē
uns1dzē
irk1stē
ild1krē
ink1sli
urs1trā
unk1sto
ilk1stē
ārg1sto
akt1sgu
ert1bri
ilg1sti
ērt1svē
ērs1gri
aps1trē
eņs1krā
amp1stu
ats1trā
ilp1sti
ežs1trā
erk1šķi
eln1pla
urk1sni
akt1svi
ens1dzi
irg1sti
ark1šķu
ess1krā
irk1sto
unt1sma
isn1gri
alk1sne
ild1pla
udz1ska
ārs1tru
uzs1krū
ink1šķē
ērs1svī
ērk1šķo
īks1tpi
ilt1rpa
ātr1bra
urk1stu
ārs1pro
als1sti
eks1plo
amp1sto
izs1tre
ang1ste
irg1sta
izs1krē
ātr1spē
ust1knā
ark1šķē
ark1šķi
ārs1prā
aps1prū
ilp1sto
īgs1trā
ont1rre
akt1sde
ats1tre
uzs1trī
aps1pļa
urk1šķi
urk1ste
ink1stu
ājs1trā
ats1pļa
ērk1šķi
etr1stū
ink1sta
ans1kri
eks1pro
ald1drā
ārp1sta
urb1sta
unk1šķē
akt1sda
akt1spu
alk1sni
ārg1sta
āls1tra
āls1ste
irg1zde
āgs1tvi
ird1zni
irt1sku
ons1trā
ērk1sta
ilp1sta
isn1stū
elk1sni
ilt1sko
ats1prū
urk1šķu
ars1tga
ugs1tro
ens1šķi
ing1sti
ads1krū
els1tra
ark1šķa
ark1sto
ant1sbe
ink1šķa
unk1sti
ird1sde
ink1sti
ans1pla
ugs1tra
ats1pre
irk1šķi
irp1stu
ils1dru
als1tni
ats1tru
ins1tru
anž1dze
īks1pro
amp1sti
ars1tvī
ugš1stā
anc1spē
ark1sti
unk1sta
irm1ska
akt1smī
ulg1stu
amp1sta
eks1trī
unk1šķo
urk1stē
elz1szā
ārs1tre
ens1kri
ink1šķe
uks1trā
ink1sto
ult1spū
elt1spē
ats1pri
ild1spē
uzs1prū
eks1tro
egl1prā
irp1sto
alt1kri
akņ1gra
ārs1lve
ārs1pļa
udz1stū
urb1sto
aps1tre
ugs1tvē
ekļ1skā
unk1šķa
isn1prā
ats1tri
ākļ1stā
udz1krā
imt1pro
ing1sta
eks1plu
akt1spa
ilk1sta
alk1šņa
ats1prā
īks1tča
ent1rti
ērk1sti
irg1spē
ikt1spē
izs1prā
akt1smi
izs1krū
unk1stu
ats1krū
ārs1pri
unk1šķu
ult1spē
unt1sga
ugs1tsi
izs1pri
ārs1krū
aps1krū
ārk1sti
izs1pļa
ars1tpu
ērk1ste
uzs1tri
ulb1sta
izs1tri
ons1tru
irs1svā
ats1trī
ārs1krē
akt1ssa
eks1tra
akt1slo
urk1šķo
ing1stu
ult1kva
ust1spo
ītņ1gri
ežs1krū
irm1sle
irk1sta
urk1šķē
ort1pre
ekš1ņla
iņs1trā
alk1sta
irk1stu
emm1dzi
irg1zdā
irm1kla
aks1tni
ons1tra
ink1šķu
ats1kra
ind1rve
akt1sja
ens1blu
aļķ1špa
ult1sva
ogļ1skā
ārk1sta
ulg1sti
ērk1sto
ird1sdā
ugs1tce
uns1grē
ult1pla
irš1krā
egt1spē
ārs1tni
ats1pro
akt1sla
ārs1tri
ilg1stu
īdz1sva
uzs1krē
oks1krū
ārt1sta
ilb1sta
alk1sti
oks1tro
ekš1dzi
ent1rbē
iln1ska
irm1šķi
ārs1trā
aps1pri
ons1krē
ārs1pre
irk1ste
ird1slē
ulg1sta
akš1svā
alt1bri
ārs1prū
.jā1s2p
.ne1s2p
.ie1s2p
.no1s2p
.pa1s2p
.pie1s2p
.sa1s2p
.uz1s2p
.aiz1s2p
.ap1s2p
.at1s2p
.bez1s2p
.pār1s2p
.iz1s2p
.eks1s2p
.vis1s2p
.jā1t2r
.ne1t2r
.ie1t2r
.no1t2r
.pa1t2r
.pie1t2r
.sa1t2r
.uz1t2r
.aiz1t2r
.ap1t2r
.at1t2r
.bez1t2r
.pār1t2r
.iz1t2r
.eks1t2r
.vis1t2r
.jā1s2c
.ne1s2c
.ie1s2c
.no1s2c
.pa1s2c
.pie1s2c
.sa1s2c
.uz1s2c
.aiz1s2c
.ap1s2c
.at1s2c
.bez1s2c
.pār1s2c
.iz1s2c
.eks1s2c
.vis1s2c
.jā1s2tj
.ne1s2tj
.ie1s2tj
.no1s2tj
.pa1s2tj
.pie1s2tj
.sa1s2tj
.uz1s2tj
.aiz1s2tj
.ap1s2tj
.at1s2tj
.bez1s2tj
.pār1s2tj
.iz1s2tj
.eks1s2tj
.vis1s2tj
.jā1g2l
.ne1g2l
.ie1g2l
.no1g2l
.pa1g2l
.pie1g2l
.sa1g2l
.uz1g2l
.aiz1g2l
.ap1g2l
.at1g2l
.bez1g2l
.pār1g2l
.iz1g2l
.eks1g2l
.vis1g2l
.jā1ž2v
.ne1ž2v
.ie1ž2v
.no1ž2v
.pa1ž2v
.pie1ž2v
.sa1ž2v
.uz1ž2v
.aiz1ž2v
.ap1ž2v
.at1ž2v
.bez1ž2v
.pār1ž2v
.iz1ž2v
.eks1ž2v
.vis1ž2v
.jā1š2ļ
.ne1š2ļ
.ie1š2ļ
.no1š2ļ
.pa1š2ļ
.pie1š2ļ
.sa1š2ļ
.uz1š2ļ
.aiz1š2ļ
.ap1š2ļ
.at1š2ļ
.bez1š2ļ
.pār1š2ļ
.iz1š2ļ
.eks1š2ļ
.vis1š2ļ
.jā1s2f
.ne1s2f
.ie1s2f
.no1s2f
.pa1s2f
.pie1s2f
.sa1s2f
.uz1s2f
.aiz1s2f
.ap1s2f
.at1s2f
.bez1s2f
.pār1s2f
.iz1s2f
.eks1s2f
.vis1s2f
.jā1š2t
.ne1š2t
.ie1š2t
.no1š2t
.pa1š2t
.pie1š2t
.sa1š2t
.uz1š2t
.aiz1š2t
.ap1š2t
.at1š2t
.bez1š2t
.pār1š2t
.iz1š2t
.eks1š2t
.vis1š2t
.jā1s2tr
.ne1s2tr
.ie1s2tr
.no1s2tr
.pa1s2tr
.pie1s2tr
.sa1s2tr
.uz1s2tr
.aiz1s2tr
.ap1s2tr
.at1s2tr
.bez1s2tr
.pār1s2tr
.iz1s2tr
.eks1s2tr
.vis1s2tr
.jā1b2r
.ne1b2r
.ie1b2r
.no1b2r
.pa1b2r
.pie1b2r
.sa1b2r
.uz1b2r
.aiz1b2r
.ap1b2r
.at1b2r
.bez1b2r
.pār1b2r
.iz1b2r
.eks1b2r
.vis1b2r
.jā1š2r
.ne1š2r
.ie1š2r
.no1š2r
.pa1š2r
.pie1š2r
.sa1š2r
.uz1š2r
.aiz1š2r
.ap1š2r
.at1š2r
.bez1š2r
.pār1š2r
.iz1š2r
.eks1š2r
.vis1š2r
.jā1š2v
.ne1š2v
.ie1š2v
.no1š2v
.pa1š2v
.pie1š2v
.sa1š2v
.uz1š2v
.aiz1š2v
.ap1š2v
.at1š2v
.bez1š2v
.pār1š2v
.iz1š2v
.eks1š2v
.vis1š2v
.jā1s2t
.ne1s2t
.ie1s2t
.no1s2t
.pa1s2t
.pie1s2t
.sa1s2t
.uz1s2t
.aiz1s2t
.ap1s2t
.at1s2t
.bez1s2t
.pār1s2t
.iz1s2t
.eks1s2t
.vis1s2t
.jā1p2r
.ne1p2r
.ie1p2r
.no1p2r
.pa1p2r
.pie1p2r
.sa1p2r
.uz1p2r
.aiz1p2r
.ap1p2r
.at1p2r
.bez1p2r
.pār1p2r
.iz1p2r
.eks1p2r
.vis1p2r
.jā1g2ļ
.ne1g2ļ
.ie1g2ļ
.no1g2ļ
.pa1g2ļ
.pie1g2ļ
.sa1g2ļ
.uz1g2ļ
.aiz1g2ļ
.ap1g2ļ
.at1g2ļ
.bez1g2ļ
.pār1g2ļ
.iz1g2ļ
.eks1g2ļ
.vis1g2ļ
.jā1š2k
.ne1š2k
.ie1š2k
.no1š2k
.pa1š2k
.pie1š2k
.sa1š2k
.uz1š2k
.aiz1š2k
.ap1š2k
.at1š2k
.bez1š2k
.pār1š2k
.iz1š2k
.eks1š2k
.vis1š2k
.jā1p2s
.ne1p2s
.ie1p2s
.no1p2s
.pa1p2s
.pie1p2s
.sa1p2s
.uz1p2s
.aiz1p2s
.ap1p2s
.at1p2s
.bez1p2s
.pār1p2s
.iz1p2s
.eks1p2s
.vis1p2s
.jā1k2l
.ne1k2l
.ie1k2l
.no1k2l
.pa1k2l
.pie1k2l
.sa1k2l
.uz1k2l
.aiz1k2l
.ap1k2l
.at1k2l
.bez1k2l
.pār1k2l
.iz1k2l
.eks1k2l
.vis1k2l
.jā1g2r
.ne1g2r
.ie1g2r
.no1g2r
.pa1g2r
.pie1g2r
.sa1g2r
.uz1g2r
.aiz1g2r
.ap1g2r
.at1g2r
.bez1g2r
.pār1g2r
.iz1g2r
.eks1g2r
.vis1g2r
.jā1š2ķ
.ne1š2ķ
.ie1š2ķ
.no1š2ķ
.pa1š2ķ
.pie1š2ķ
.sa1š2ķ
.uz1š2ķ
.aiz1š2ķ
.ap1š2ķ
.at1š2ķ
.bez1š2ķ
.pār1š2ķ
.iz1š2ķ
.eks1š2ķ
.vis1š2ķ
.jā1p2n
.ne1p2n
.ie1p2n
.no1p2n
.pa1p2n
.pie1p2n
.sa1p2n
.uz1p2n
.aiz1p2n
.ap1p2n
.at1p2n
.bez1p2n
.pār1p2n
.iz1p2n
.eks1p2n
.vis1p2n
.jā1s2v
.ne1s2v
.ie1s2v
.no1s2v
.pa1s2v
.pie1s2v
.sa1s2v
.uz1s2v
.aiz1s2v
.ap1s2v
.at1s2v
.bez1s2v
.pār1s2v
.iz1s2v
.eks1s2v
.vis1s2v
.jā1s2pr
.ne1s2pr
.ie1s2pr
.no1s2pr
.pa1s2pr
.pie1s2pr
.sa1s2pr
.uz1s2pr
.aiz1s2pr
.ap1s2pr
.at1s2pr
.bez1s2pr
.pār1s2pr
.iz1s2pr
.eks1s2pr
.vis1s2pr
.jā1d2r
.ne1d2r
.ie1d2r
.no1d2r
.pa1d2r
.pie1d2r
.sa1d2r
.uz1d2r
.aiz1d2r
.ap1d2r
.at1d2r
.bez1d2r
.pār1d2r
.iz1d2r
.eks1d2r
.vis1d2r
.jā1p2l
.ne1p2l
.ie1p2l
.no1p2l
.pa1p2l
.pie1p2l
.sa1p2l
.uz1p2l
.aiz1p2l
.ap1p2l
.at1p2l
.bez1p2l
.pār1p2l
.iz1p2l
.eks1p2l
.vis1p2l
.jā1d2v
.ne1d2v
.ie1d2v
.no1d2v
.pa1d2v
.pie1d2v
.sa1d2v
.uz1d2v
.aiz1d2v
.ap1d2v
.at1d2v
.bez1d2v
.pār1d2v
.iz1d2v
.eks1d2v
.vis1d2v
.jā1š2l
.ne1š2l
.ie1š2l
.no1š2l
.pa1š2l
.pie1š2l
.sa1š2l
.uz1š2l
.aiz1š2l
.ap1š2l
.at1š2l
.bez1š2l
.pār1š2l
.iz1š2l
.eks1š2l
.vis1š2l
.jā1s2k
.ne1s2k
.ie1s2k
.no1s2k
.pa1s2k
.pie1s2k
.sa1s2k
.uz1s2k
.aiz1s2k
.ap1s2k
.at1s2k
.bez1s2k
.pār1s2k
.iz1s2k
.eks1s2k
.vis1s2k
.jā1s2kv
.ne1s2kv
.ie1s2kv
.no1s2kv
.pa1s2kv
.pie1s2kv
.sa1s2kv
.uz1s2kv
.aiz1s2kv
.ap1s2kv
.at1s2kv
.bez1s2kv
.pār1s2kv
.iz1s2kv
.eks1s2kv
.vis1s2kv
.jā1k2v
.ne1k2v
.ie1k2v
.no1k2v
.pa1k2v
.pie1k2v
.sa1k2v
.uz1k2v
.aiz1k2v
.ap1k2v
.at1k2v
.bez1k2v
.pār1k2v
.iz1k2v
.eks1k2v
.vis1k2v
.jā1z2v
.ne1z2v
.ie1z2v
.no1z2v
.pa1z2v
.pie1z2v
.sa1z2v
.uz1z2v
.aiz1z2v
.ap1z2v
.at1z2v
.bez1z2v
.pār1z2v
.iz1z2v
.eks1z2v
.vis1z2v
.jā1k2s
.ne1k2s
.ie1k2s
.no1k2s
.pa1k2s
.pie1k2s
.sa1k2s
.uz1k2s
.aiz1k2s
.ap1k2s
.at1k2s
.bez1k2s
.pār1k2s
.iz1k2s
.eks1k2s
.vis1k2s
.jā1p2t
.ne1p2t
.ie1p2t
.no1p2t
.pa1p2t
.pie1p2t
.sa1p2t
.uz1p2t
.aiz1p2t
.ap1p2t
.at1p2t
.bez1p2t
.pār1p2t
.iz1p2t
.eks1p2t
.vis1p2t
.jā1z2n
.ne1z2n
.ie1z2n
.no1z2n
.pa1z2n
.pie1z2n
.sa1z2n
.uz1z2n
.aiz1z2n
.ap1z2n
.at1z2n
.bez1z2n
.pār1z2n
.iz1z2n
.eks1z2n
.vis1z2n
.jā1k2r
.ne1k2r
.ie1k2r
.no1k2r
.pa1k2r
.pie1k2r
.sa1k2r
.uz1k2r
.aiz1k2r
.ap1k2r
.at1k2r
.bez1k2r
.pār1k2r
.iz1k2r
.eks1k2r
.vis1k2r
.jā1s2kr
.ne1s2kr
.ie1s2kr
.no1s2kr
.pa1s2kr
.pie1s2kr
.sa1s2kr
.uz1s2kr
.aiz1s2kr
.ap1s2kr
.at1s2kr
.bez1s2kr
.pār1s2kr
.iz1s2kr
.eks1s2kr
.vis1s2kr
.jā1f2r
.ne1f2r
.ie1f2r
.no1f2r
.pa1f2r
.pie1f2r
.sa1f2r
.uz1f2r
.aiz1f2r
.ap1f2r
.at1f2r
.bez1f2r
.pār1f2r
.iz1f2r
.eks1f2r
.vis1f2r
.jā1s2h
.ne1s2h
.ie1s2h
.no1s2h
.pa1s2h
.pie1s2h
.sa1s2h
.uz1s2h
.aiz1s2h
.ap1s2h
.at1s2h
.bez1s2h
.pār1s2h
.iz1s2h
.eks1s2h
.vis1s2h
.jā1ž2ņ
.ne1ž2ņ
.ie1ž2ņ
.no1ž2ņ
.pa1ž2ņ
.pie1ž2ņ
.sa1ž2ņ
.uz1ž2ņ
.aiz1ž2ņ
.ap1ž2ņ
.at1ž2ņ
.bez1ž2ņ
.pār1ž2ņ
.iz1ž2ņ
.eks1ž2ņ
.vis1ž2ņ
.jā1d2d
.ne1d2d
.ie1d2d
.no1d2d
.pa1d2d
.pie1d2d
.sa1d2d
.uz1d2d
.aiz1d2d
.ap1d2d
.at1d2d
.bez1d2d
.pār1d2d
.iz1d2d
.eks1d2d
.vis1d2d
.jā1š2pr
.ne1š2pr
.ie1š2pr
.no1š2pr
.pa1š2pr
.pie1š2pr
.sa1š2pr
.uz1š2pr
.aiz1š2pr
.ap1š2pr
.at1š2pr
.bez1š2pr
.pār1š2pr
.iz1š2pr
.eks1š2pr
.vis1š2pr
.jā1v2j
.ne1v2j
.ie1v2j
.no1v2j
.pa1v2j
.pie1v2j
.sa1v2j
.uz1v2j
.aiz1v2j
.ap1v2j
.at1v2j
.bez1v2j
.pār1v2j
.iz1v2j
.eks1v2j
.vis1v2j
.jā1f2j
.ne1f2j
.ie1f2j
.no1f2j
.pa1f2j
.pie1f2j
.sa1f2j
.uz1f2j
.aiz1f2j
.ap1f2j
.at1f2j
.bez1f2j
.pār1f2j
.iz1f2j
.eks1f2j
.vis1f2j
.jā1p2j
.ne1p2j
.ie1p2j
.no1p2j
.pa1p2j
.pie1p2j
.sa1p2j
.uz1p2j
.aiz1p2j
.ap1p2j
.at1p2j
.bez1p2j
.pār1p2j
.iz1p2j
.eks1p2j
.vis1p2j
.jā1b2ļ
.ne1b2ļ
.ie1b2ļ
.no1b2ļ
.pa1b2ļ
.pie1b2ļ
.sa1b2ļ
.uz1b2ļ
.aiz1b2ļ
.ap1b2ļ
.at1b2ļ
.bez1b2ļ
.pār1b2ļ
.iz1b2ļ
.eks1b2ļ
.vis1b2ļ
.jā1g2n
.ne1g2n
.ie1g2n
.no1g2n
.pa1g2n
.pie1g2n
.sa1g2n
.uz1g2n
.aiz1g2n
.ap1g2n
.at1g2n
.bez1g2n
.pār1g2n
.iz1g2n
.eks1g2n
.vis1g2n
.jā1h2r
.ne1h2r
.ie1h2r
.no1h2r
.pa1h2r
.pie1h2r
.sa1h2r
.uz1h2r
.aiz1h2r
.ap1h2r
.at1h2r
.bez1h2r
.pār1h2r
.iz1h2r
.eks1h2r
.vis1h2r
.jā1s2n
.ne1s2n
.ie1s2n
.no1s2n
.pa1s2n
.pie1s2n
.sa1s2n
.uz1s2n
.aiz1s2n
.ap1s2n
.at1s2n
.bez1s2n
.pār1s2n
.iz1s2n
.eks1s2n
.vis1s2n
.jā1ž2m
.ne1ž2m
.ie1ž2m
.no1ž2m
.pa1ž2m
.pie1ž2m
.sa1ž2m
.uz1ž2m
.aiz1ž2m
.ap1ž2m
.at1ž2m
.bez1ž2m
.pār1ž2m
.iz1ž2m
.eks1ž2m
.vis1ž2m
.jā1d2ž
.ne1d2ž
.ie1d2ž
.no1d2ž
.pa1d2ž
.pie1d2ž
.sa1d2ž
.uz1d2ž
.aiz1d2ž
.ap1d2ž
.at1d2ž
.bez1d2ž
.pār1d2ž
.iz1d2ž
.eks1d2ž
.vis1d2ž
.jā1k2c
.ne1k2c
.ie1k2c
.no1k2c
.pa1k2c
.pie1k2c
.sa1k2c
.uz1k2c
.aiz1k2c
.ap1k2c
.at1k2c
.bez1k2c
.pār1k2c
.iz1k2c
.eks1k2c
.vis1k2c
.jā1k2ņ
.ne1k2ņ
.ie1k2ņ
.no1k2ņ
.pa1k2ņ
.pie1k2ņ
.sa1k2ņ
.uz1k2ņ
.aiz1k2ņ
.ap1k2ņ
.at1k2ņ
.bez1k2ņ
.pār1k2ņ
.iz1k2ņ
.eks1k2ņ
.vis1k2ņ
.jā1š2m
.ne1š2m
.ie1š2m
.no1š2m
.pa1š2m
.pie1š2m
.sa1š2m
.uz1š2m
.aiz1š2m
.ap1š2m
.at1š2m
.bez1š2m
.pār1š2m
.iz1š2m
.eks1š2m
.vis1š2m
.jā1g2v
.ne1g2v
.ie1g2v
.no1g2v
.pa1g2v
.pie1g2v
.sa1g2v
.uz1g2v
.aiz1g2v
.ap1g2v
.at1g2v
.bez1g2v
.pār1g2v
.iz1g2v
.eks1g2v
.vis1g2v
.jā1h2l
.ne1h2l
.ie1h2l
.no1h2l
.pa1h2l
.pie1h2l
.sa1h2l
.uz1h2l
.aiz1h2l
.ap1h2l
.at1h2l
.bez1h2l
.pār1h2l
.iz1h2l
.eks1h2l
.vis1h2l
.jā1k2ļ
.ne1k2ļ
.ie1k2ļ
.no1k2ļ
.pa1k2ļ
.pie1k2ļ
.sa1k2ļ
.uz1k2ļ
.aiz1k2ļ
.ap1k2ļ
.at1k2ļ
.bez1k2ļ
.pār1k2ļ
.iz1k2ļ
.eks1k2ļ
.vis1k2ļ
.jā1s2l
.ne1s2l
.ie1s2l
.no1s2l
.pa1s2l
.pie1s2l
.sa1s2l
.uz1s2l
.aiz1s2l
.ap1s2l
.at1s2l
.bez1s2l
.pār1s2l
.iz1s2l
.eks1s2l
.vis1s2l
.jā1t2v
.ne1t2v
.ie1t2v
.no1t2v
.pa1t2v
.pie1t2v
.sa1t2v
.uz1t2v
.aiz1t2v
.ap1t2v
.at1t2v
.bez1t2v
.pār1t2v
.iz1t2v
.eks1t2v
.vis1t2v
.jā1š2ņ
.ne1š2ņ
.ie1š2ņ
.no1š2ņ
.pa1š2ņ
.pie1š2ņ
.sa1š2ņ
.uz1š2ņ
.aiz1š2ņ
.ap1š2ņ
.at1š2ņ
.bez1š2ņ
.pār1š2ņ
.iz1š2ņ
.eks1š2ņ
.vis1š2ņ
.jā1š2p
.ne1š2p
.ie1š2p
.no1š2p
.pa1š2p
.pie1š2p
.sa1š2p
.uz1š2p
.aiz1š2p
.ap1š2p
.at1š2p
.bez1š2p
.pār1š2p
.iz1š2p
.eks1š2p
.vis1š2p
.jā1d2z
.ne1d2z
.ie1d2z
.no1d2z
.pa1d2z
.pie1d2z
.sa1d2z
.uz1d2z
.aiz1d2z
.ap1d2z
.at1d2z
.bez1d2z
.pār1d2z
.iz1d2z
.eks1d2z
.vis1d2z
.jā1f2l
.ne1f2l
.ie1f2l
.no1f2l
.pa1f2l
.pie1f2l
.sa1f2l
.uz1f2l
.aiz1f2l
.ap1f2l
.at1f2l
.bez1f2l
.pār1f2l
.iz1f2l
.eks1f2l
.vis1f2l
.jā1k2n
.ne1k2n
.ie1k2n
.no1k2n
.pa1k2n
.pie1k2n
.sa1k2n
.uz1k2n
.aiz1k2n
.ap1k2n
.at1k2n
.bez1k2n
.pār1k2n
.iz1k2n
.eks1k2n
.vis1k2n
.jā1p2ļ
.ne1p2ļ
.ie1p2ļ
.no1p2ļ
.pa1p2ļ
.pie1p2ļ
.sa1p2ļ
.uz1p2ļ
.aiz1p2ļ
.ap1p2ļ
.at1p2ļ
.bez1p2ļ
.pār1p2ļ
.iz1p2ļ
.eks1p2ļ
.vis1p2ļ
.jā1s2pļ
.ne1s2pļ
.ie1s2pļ
.no1s2pļ
.pa1s2pļ
.pie1s2pļ
.sa1s2pļ
.uz1s2pļ
.aiz1s2pļ
.ap1s2pļ
.at1s2pļ
.bez1s2pļ
.pār1s2pļ
.iz1s2pļ
.eks1s2pļ
.vis1s2pļ
.jā1s2kl
.ne1s2kl
.ie1s2kl
.no1s2kl
.pa1s2kl
.pie1s2kl
.sa1s2kl
.uz1s2kl
.aiz1s2kl
.ap1s2kl
.at1s2kl
.bez1s2kl
.pār1s2kl
.iz1s2kl
.eks1s2kl
.vis1s2kl
.jā1k2b
.ne1k2b
.ie1k2b
.no1k2b
.pa1k2b
.pie1k2b
.sa1k2b
.uz1k2b
.aiz1k2b
.ap1k2b
.at1k2b
.bez1k2b
.pār1k2b
.iz1k2b
.eks1k2b
.vis1k2b
.jā1s2m
.ne1s2m
.ie1s2m
.no1s2m
.pa1s2m
.pie1s2m
.sa1s2m
.uz1s2m
.aiz1s2m
.ap1s2m
.at1s2m
.bez1s2m
.pār1s2m
.iz1s2m
.eks1s2m
.vis1s2m
.jā1m2n
.ne1m2n
.ie1m2n
.no1m2n
.pa1m2n
.pie1m2n
.sa1m2n
.uz1m2n
.aiz1m2n
.ap1m2n
.at1m2n
.bez1m2n
.pār1m2n
.iz1m2n
.eks1m2n
.vis1m2n
.jā1š2n
.ne1š2n
.ie1š2n
.no1š2n
.pa1š2n
.pie1š2n
.sa1š2n
.uz1š2n
.aiz1š2n
.ap1š2n
.at1š2n
.bez1š2n
.pār1š2n
.iz1š2n
.eks1š2n
.vis1š2n
.jā1v2r
.ne1v2r
.ie1v2r
.no1v2r
.pa1v2r
.pie1v2r
.sa1v2r
.uz1v2r
.aiz1v2r
.ap1v2r
.at1v2r
.bez1v2r
.pār1v2r
.iz1v2r
.eks1v2r
.vis1v2r
.jā1b2l
.ne1b2l
.ie1b2l
.no1b2l
.pa1b2l
.pie1b2l
.sa1b2l
.uz1b2l
.aiz1b2l
.ap1b2l
.at1b2l
.bez1b2l
.pār1b2l
.iz1b2l
.eks1b2l
.vis1b2l
2b3dams.
2c3dams.
2č3dams.
2d3dams.
2f3dams.
2g3dams.
2ģ3dams.
2h3dams.
2j3dams.
2k3dams.
2ķ3dams.
2l3dams.
2ļ3dams.
2m3dams.
2n3dams.
2ņ3dams.
2p3dams.
2r3dams.
2s3dams.
2š3dams.
2t3dams.
2v3dams.
2z3dams.
2ž3dams.
2b3da3ma.
2c3da3ma.
2č3da3ma.
2d3da3ma.
2f3da3ma.
2g3da3ma.
2ģ3da3ma.
2h3da3ma.
2j3da3ma.
2k3da3ma.
2ķ3da3ma.
2l3da3ma.
2ļ3da3ma.
2m3da3ma.
2n3da3ma.
2ņ3da3ma.
2p3da3ma.
2r3da3ma.
2s3da3ma.
2š3da3ma.
2t3da3ma.
2v3da3ma.
2z3da3ma.
2ž3da3ma.
2b3da3mies.
2c3da3mies.
2č3da3mies.
2d3da3mies.
2f3da3mies.
2g3da3mies.
2ģ3da3mies.
2h3da3mies.
2j3da3mies.
2k3da3mies.
2ķ3da3mies.
2l3da3mies.
2ļ3da3mies.
2m3da3mies.
2n3da3mies.
2ņ3da3mies.
2p3da3mies.
2r3da3mies.
2s3da3mies.
2š3da3mies.
2t3da3mies.
2v3da3mies.
2z3da3mies.
2ž3da3mies.
2b3da3mās.
2c3da3mās.
2č3da3mās.
2d3da3mās.
2f3da3mās.
2g3da3mās.
2ģ3da3mās.
2h3da3mās.
2j3da3mās.
2k3da3mās.
2ķ3da3mās.
2l3da3mās.
2ļ3da3mās.
2m3da3mās.
2n3da3mās.
2ņ3da3mās.
2p3da3mās.
2r3da3mās.
2s3da3mās.
2š3da3mās.
2t3da3mās.
2v3da3mās.
2z3da3mās.
2ž3da3mās.
2b3gans.
2c3gans.
2č3gans.
2d3gans.
2f3gans.
2g3gans.
2ģ3gans.
2h3gans.
2j3gans.
2k3gans.
2ķ3gans.
2l3gans.
2ļ3gans.
2m3gans.
2n3gans.
2ņ3gans.
2p3gans.
2r3gans.
2s3gans.
2š3gans.
2t3gans.
2v3gans.
2z3gans.
2ž3gans.
2b3ga3na.
2c3ga3na.
2č3ga3na.
2d3ga3na.
2f3ga3na.
2g3ga3na.
2ģ3ga3na.
2h3ga3na.
2j3ga3na.
2k3ga3na.
2ķ3ga3na.
2l3ga3na.
2ļ3ga3na.
2m3ga3na.
2n3ga3na.
2ņ3ga3na.
2p3ga3na.
2r3ga3na.
2s3ga3na.
2š3ga3na.
2t3ga3na.
2v3ga3na.
2z3ga3na.
2ž3ga3na.
2b3nieks.
2c3nieks.
2č3nieks.
2d3nieks.
2f3nieks.
2g3nieks.
2ģ3nieks.
2h3nieks.
2j3nieks.
2k3nieks.
2ķ3nieks.
2l3nieks.
2ļ3nieks.
2m3nieks.
2n3nieks.
2ņ3nieks.
2p3nieks.
2r3nieks.
2s3nieks.
2š3nieks.
2t3nieks.
2v3nieks.
2z3nieks.
2ž3nieks.
2b3nie3ce.
2c3nie3ce.
2č3nie3ce.
2d3nie3ce.
2f3nie3ce.
2g3nie3ce.
2ģ3nie3ce.
2h3nie3ce.
2j3nie3ce.
2k3nie3ce.
2ķ3nie3ce.
2l3nie3ce.
2ļ3nie3ce.
2m3nie3ce.
2n3nie3ce.
2ņ3nie3ce.
2p3nie3ce.
2r3nie3ce.
2s3nie3ce.
2š3nie3ce.
2t3nie3ce.
2v3nie3ce.
2z3nie3ce.
2ž3nie3ce.
2b3nī3ca.
2c3nī3ca.
2č3nī3ca.
2d3nī3ca.
2f3nī3ca.
2g3nī3ca.
2ģ3nī3ca.
2h3nī3ca.
2j3nī3ca.
2k3nī3ca.
2ķ3nī3ca.
2l3nī3ca.
2ļ3nī3ca.
2m3nī3ca.
2n3nī3ca.
2ņ3nī3ca.
2p3nī3ca.
2r3nī3ca.
2s3nī3ca.
2š3nī3ca.
2t3nī3ca.
2v3nī3ca.
2z3nī3ca.
2ž3nī3ca.
2b3ša3na.
2c3ša3na.
2č3ša3na.
2d3ša3na.
2f3ša3na.
2g3ša3na.
2ģ3ša3na.
2h3ša3na.
2j3ša3na.
2k3ša3na.
2ķ3ša3na.
2l3ša3na.
2ļ3ša3na.
2m3ša3na.
2n3ša3na.
2ņ3ša3na.
2p3ša3na.
2r3ša3na.
2s3ša3na.
2š3ša3na.
2t3ša3na.
2v3ša3na.
2z3ša3na.
2ž3ša3na.
2b3ša3nās.
2c3ša3nās.
2č3ša3nās.
2d3ša3nās.
2f3ša3nās.
2g3ša3nās.
2ģ3ša3nās.
2h3ša3nās.
2j3ša3nās.
2k3ša3nās.
2ķ3ša3nās.
2l3ša3nās.
2ļ3ša3nās.
2m3ša3nās.
2n3ša3nās.
2ņ3ša3nās.
2p3ša3nās.
2r3ša3nās.
2s3ša3nās.
2š3ša3nās.
2t3ša3nās.
2v3ša3nās.
2z3ša3nās.
2ž3ša3nās.
2b3ta3la.
2c3ta3la.
2č3ta3la.
2d3ta3la.
2f3ta3la.
2g3ta3la.
2ģ3ta3la.
2h3ta3la.
2j3ta3la.
2k3ta3la.
2ķ3ta3la.
2l3ta3la.
2ļ3ta3la.
2m3ta3la.
2n3ta3la.
2ņ3ta3la.
2p3ta3la.
2r3ta3la.
2s3ta3la.
2š3ta3la.
2t3ta3la.
2v3ta3la.
2z3ta3la.
2ž3ta3la.
2b3tu3ve.
2c3tu3ve.
2č3tu3ve.
2d3tu3ve.
2f3tu3ve.
2g3tu3ve.
2ģ3tu3ve.
2h3tu3ve.
2j3tu3ve.
2k3tu3ve.
2ķ3tu3ve.
2l3tu3ve.
2ļ3tu3ve.
2m3tu3ve.
2n3tu3ve.
2ņ3tu3ve.
2p3tu3ve.
2r3tu3ve.
2s3tu3ve.
2š3tu3ve.
2t3tu3ve.
2v3tu3ve.
2z3tu3ve.
2ž3tu3ve.
.jā3a2
.ne3a2
.ie3a2
.no3a2
.pa3a2
.pie3a2
.sa3a2
.uz3a2
.aiz3a2
.ap3a2
.at3a2
.bez3a2
.pār3a2
.iz3a2
.eks3a2
.vis3a2
.jā3ā2
.ne3ā2
.ie3ā2
.no3ā2
.pa3ā2
.pie3ā2
.sa3ā2
.uz3ā2
.aiz3ā2
.ap3ā2
.at3ā2
.bez3ā2
.pār3ā2
.iz3ā2
.eks3ā2
.vis3ā2
.jā3e2
.ne3e2
.ie3e2
.no3e2
.pa3e2
.pie3e2
.sa3e2
.uz3e2
.aiz3e2
.ap3e2
.at3e2
.bez3e2
.pār3e2
.iz3e2
.eks3e2
.vis3e2
.jā3ē2
.ne3ē2
.ie3ē2
.no3ē2
.pa3ē2
.pie3ē2
.sa3ē2
.uz3ē2
.aiz3ē2
.ap3ē2
.at3ē2
.bez3ē2
.pār3ē2
.iz3ē2
.eks3ē2
.vis3ē2
.jā3i2
.ne3i2
.ie3i2
.no3i2
.pa3i2
.pie3i2
.sa3i2
.uz3i2
.aiz3i2
.ap3i2
.at3i2
.bez3i2
.pār3i2
.iz3i2
.eks3i2
.vis3i2
.jā3ī2
.ne3ī2
.ie3ī2
.no3ī2
.pa3ī2
.pie3ī2
.sa3ī2
.uz3ī2
.aiz3ī2
.ap3ī2
.at3ī2
.bez3ī2
.pār3ī2
.iz3ī2
.eks3ī2
.vis3ī2
.jā3o2
.ne3o2
.ie3o2
.no3o2
.pa3o2
.pie3o2
.sa3o2
.uz3o2
.aiz3o2
.ap3o2
.at3o2
.bez3o2
.pār3o2
.iz3o2
.eks3o2
.vis3o2
.jā3u2
.ne3u2
.ie3u2
.no3u2
.pa3u2
.pie3u2
.sa3u2
.uz3u2
.aiz3u2
.ap3u2
.at3u2
.bez3u2
.pār3u2
.iz3u2
.eks3u2
.vis3u2
.jā3ū2
.ne3ū2
.ie3ū2
.no3ū2
.pa3ū2
.pie3ū2
.sa3ū2
.uz3ū2
.aiz3ū2
.ap3ū2
.at3ū2
.bez3ū2
.pār3ū2
.iz3ū2
.eks3ū2
.vis3ū2
.jā3ie1
.jā3iz1
.jā3no1
.ne3aiz1
.ne3ap1
.ne3ie1
.ne3at1
.ne3in1
.ne3iz1
.ne3sa
.ne3uz1
.priek2š1
4d5ze1me
.tur2p1m
il2k1tie
.spil2g1t
mē1ne2š1
1pa1d2smit
g2š1gal
k2š1gal
tran2s
1port
vēs2t1n
vēs2t1k
pa2t3stā
pa2s2t3k
pa2s2t3m
pa2s2t2s.
pa2r2k2s.
pa2r3ket
sa2ls.
sa2lds.
sa2l2d1
pir2m1r
pir2m1k
pir2m2s1
ot2r1r2
ot2r1k2
ir2k3l
ir2k3ļ
.adā2m3
.ai4z5
ak3me4ņ3
apak2š3
ap1au
kār2t3n
aug2s2t3
.at3e2j
bal2t3ma
.vie2n1
}

